/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/componentchooser/componentconfig_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef COMPONENTCONFIG_UI_H
#define COMPONENTCONFIG_UI_H

#include <qvariant.h>
#include <qwidget.h>
#include <kcombobox.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QLabel;
class KComboBox;

class ComponentConfig_UI : public QWidget
{
    Q_OBJECT

public:
    ComponentConfig_UI( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~ComponentConfig_UI();

    QLabel* ChooserDocu;
    KComboBox* ComponentSelector;

protected:
    QVBoxLayout* ComponentConfig_UILayout;
    QSpacerItem* Spacer2;

protected slots:
    virtual void languageChange();

};

#endif // COMPONENTCONFIG_UI_H
