/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/kio/kproxydlg_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef PROXYDLGUI_H
#define PROXYDLGUI_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QButtonGroup;
class QRadioButton;
class KURLRequester;
class QPushButton;
class KLineEdit;
class QLabel;
class QCheckBox;

class KProxyDialogUI : public QWidget
{
    Q_OBJECT

public:
    KProxyDialogUI( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~KProxyDialogUI();

    QButtonGroup* gbConfigure;
    QRadioButton* rbNoProxy;
    QRadioButton* rbAutoDiscover;
    QRadioButton* rbAutoScript;
    KURLRequester* location;
    QRadioButton* rbEnvVar;
    QPushButton* pbEnvSetup;
    QRadioButton* rbManual;
    QPushButton* pbManSetup;
    QButtonGroup* gbAuth;
    QRadioButton* rbPrompt;
    QRadioButton* rbPresetLogin;
    KLineEdit* lePassword;
    KLineEdit* leUsername;
    QLabel* lbPassword;
    QLabel* lbUsername;
    QButtonGroup* gbOptions;
    QCheckBox* cbPersConn;

protected:
    QVBoxLayout* ProxyDlgUILayout;
    QVBoxLayout* gbConfigureLayout;
    QHBoxLayout* layout5;
    QSpacerItem* spacer2;
    QHBoxLayout* layout7;
    QHBoxLayout* layout6;
    QVBoxLayout* gbAuthLayout;
    QGridLayout* layout5_2;
    QSpacerItem* spacer5;
    QVBoxLayout* gbOptionsLayout;

protected slots:
    virtual void languageChange();

};

#endif // PROXYDLGUI_H
