/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/ebrowsing/plugins/ikws/searchproviderdlg_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef SEARCHPROVIDERDLGUI_H
#define SEARCHPROVIDERDLGUI_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class KLineEdit;
class QLabel;
class KComboBox;

class SearchProviderDlgUI : public QWidget
{
    Q_OBJECT

public:
    SearchProviderDlgUI( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~SearchProviderDlgUI();

    KLineEdit* leName;
    QLabel* lbCharset;
    QLabel* lbQuery;
    QLabel* lbName;
    KLineEdit* leShortcut;
    QLabel* lbShortcut;
    KLineEdit* leQuery;
    KComboBox* cbCharset;

protected:
    QGridLayout* SearchProviderDlgUILayout;

protected slots:
    virtual void languageChange();

};

#endif // SEARCHPROVIDERDLGUI_H
