/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/ebrowsing/plugins/ikws/ikwsopts_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef FILTEROPTIONSUI_H
#define FILTEROPTIONSUI_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QCheckBox;
class QLabel;
class KComboBox;
class QPushButton;
class KListView;
class QListViewItem;

class FilterOptionsUI : public QWidget
{
    Q_OBJECT

public:
    FilterOptionsUI( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~FilterOptionsUI();

    QCheckBox* cbEnableShortcuts;
    QLabel* lbDelimiter;
    QLabel* lbDefaultEngine;
    KComboBox* cmbDefaultEngine;
    QPushButton* pbChange;
    QPushButton* pbDelete;
    QPushButton* pbNew;
    KListView* lvSearchProviders;
    KComboBox* cmbDelimiter;

protected:
    QVBoxLayout* FilterOptionsUILayout;
    QGridLayout* layout10;
    QSpacerItem* spacer1;

protected slots:
    virtual void languageChange();

};

#endif // FILTEROPTIONSUI_H
