/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/konqhtml/advancedTabOptions.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef ADVANCEDTABOPTIONS_H
#define ADVANCEDTABOPTIONS_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QLabel;
class QFrame;
class QCheckBox;

class advancedTabOptions : public QWidget
{
    Q_OBJECT

public:
    advancedTabOptions( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~advancedTabOptions();

    QLabel* TextLabel3;
    QFrame* Line1;
    QCheckBox* m_pNewTabsInBackground;
    QCheckBox* m_pOpenAfterCurrentPage;
    QCheckBox* m_pTabConfirm;
    QCheckBox* m_pPermanentCloseButton;
    QCheckBox* m_pPopupsWithinTabs;
    QCheckBox* m_pTabCloseActivatePrevious;
    QCheckBox* m_pKonquerorTabforExternalURL;

protected:
    QVBoxLayout* advancedTabOptionsLayout;
    QSpacerItem* spacer;
    QVBoxLayout* layout;

protected slots:
    virtual void languageChange();

};

#endif // ADVANCEDTABOPTIONS_H
