/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/css/preview.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef PREVIEWDIALOG_H
#define PREVIEWDIALOG_H

#include <qvariant.h>
#include <qdialog.h>
#include <kseparator.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class KSeparator;
class QTextBrowser;
class QPushButton;

class PreviewDialog : public QDialog
{
    Q_OBJECT

public:
    PreviewDialog( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~PreviewDialog();

    KSeparator* Line1;
    QTextBrowser* preview;
    QPushButton* PushButton2;

protected:
    QGridLayout* PreviewDialogLayout;
    QSpacerItem* Spacer1;

protected slots:
    virtual void languageChange();

};

#endif // PREVIEWDIALOG_H
