/****************************************************************************
**
** DCOP Skeleton generated by dcopidl2cpp from moduleIface.kidl
**
** WARNING! All changes made in this file will be lost!
**
*****************************************************************************/

#include "/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/kcontrol/moduleIface.h"

#include <kdatastream.h>


static const char* const ModuleIface_ftable[6][3] = {
    { "QFont", "getFont()", "getFont()" },
    { "QPalette", "getPalette()", "getPalette()" },
    { "QString", "getStyle()", "getStyle()" },
    { "void", "invokeHandbook()", "invokeHandbook()" },
    { "void", "invokeHelp()", "invokeHelp()" },
    { 0, 0, 0 }
};
static const int ModuleIface_ftable_hiddens[5] = {
    0,
    0,
    0,
    0,
    0,
};

bool ModuleIface::process(const QCString &fun, const QByteArray &data, QCString& replyType, QByteArray &replyData)
{
    if ( fun == ModuleIface_ftable[0][1] ) { // QFont getFont()
	replyType = ModuleIface_ftable[0][0]; 
	QDataStream _replyStream( replyData, IO_WriteOnly );
	_replyStream << getFont( );
    } else if ( fun == ModuleIface_ftable[1][1] ) { // QPalette getPalette()
	replyType = ModuleIface_ftable[1][0]; 
	QDataStream _replyStream( replyData, IO_WriteOnly );
	_replyStream << getPalette( );
    } else if ( fun == ModuleIface_ftable[2][1] ) { // QString getStyle()
	replyType = ModuleIface_ftable[2][0]; 
	QDataStream _replyStream( replyData, IO_WriteOnly );
	_replyStream << getStyle( );
    } else if ( fun == ModuleIface_ftable[3][1] ) { // void invokeHandbook()
	replyType = ModuleIface_ftable[3][0]; 
	invokeHandbook( );
    } else if ( fun == ModuleIface_ftable[4][1] ) { // void invokeHelp()
	replyType = ModuleIface_ftable[4][0]; 
	invokeHelp( );
    } else {
	return DCOPObject::process( fun, data, replyType, replyData );
    }
    return true;
}

QCStringList ModuleIface::interfaces()
{
    QCStringList ifaces = DCOPObject::interfaces();
    ifaces += "ModuleIface";
    return ifaces;
}

QCStringList ModuleIface::functions()
{
    QCStringList funcs = DCOPObject::functions();
    for ( int i = 0; ModuleIface_ftable[i][2]; i++ ) {
	if (ModuleIface_ftable_hiddens[i])
	    continue;
	QCString func = ModuleIface_ftable[i][0];
	func += ' ';
	func += ModuleIface_ftable[i][2];
	funcs << func;
    }
    return funcs;
}


