/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/arts/generaltab.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef GENERALTAB_H
#define GENERALTAB_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QCheckBox;
class QFrame;
class QGroupBox;
class KRichTextLabel;
class QSlider;
class QLabel;
class KIntNumInput;
class QPushButton;

class generalTab : public QWidget
{
    Q_OBJECT

public:
    generalTab( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~generalTab();

    QCheckBox* startServer;
    QFrame* frame3;
    QGroupBox* networkedSoundGroupBox;
    KRichTextLabel* textLabel1_2;
    QCheckBox* networkTransparent;
    QGroupBox* realtimeGroupBox;
    KRichTextLabel* textLabel1;
    QCheckBox* startRealtime;
    QSlider* latencySlider;
    QLabel* textLabel5;
    QLabel* latencyLabel;
    QGroupBox* autoSuspendGroupBox;
    KRichTextLabel* textLabel5_2;
    QCheckBox* autoSuspend;
    KIntNumInput* suspendTime;
    QPushButton* testSound;

protected:
    QVBoxLayout* generalTabLayout;
    QSpacerItem* spacer5;
    QVBoxLayout* networkedSoundGroupBoxLayout;
    QGridLayout* realtimeGroupBoxLayout;
    QVBoxLayout* autoSuspendGroupBoxLayout;
    QHBoxLayout* layout7;
    QSpacerItem* spacer17_2;
    QHBoxLayout* layout3;
    QSpacerItem* spacer3_2_2;
    QSpacerItem* spacer3;

protected slots:
    virtual void languageChange();

};

#endif // GENERALTAB_H
