/****************************************************************************
**
** DCOP Skeleton generated by dcopidl2cpp from konq_historycomm.kidl
**
** WARNING! All changes made in this file will be lost!
**
*****************************************************************************/

#include "/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/libkonq/konq_historycomm.h"

#include <kdatastream.h>


static const char* const KonqHistoryComm_ftable[8][3] = {
    { "ASYNC", "notifyHistoryEntry(KonqHistoryEntry,QCString)", "notifyHistoryEntry(KonqHistoryEntry e,QCString saveId)" },
    { "ASYNC", "notifyMaxCount(Q_UINT32,QCString)", "notifyMaxCount(Q_UINT32 count,QCString saveId)" },
    { "ASYNC", "notifyMaxAge(Q_UINT32,QCString)", "notifyMaxAge(Q_UINT32 days,QCString saveId)" },
    { "ASYNC", "notifyClear(QCString)", "notifyClear(QCString saveId)" },
    { "ASYNC", "notifyRemove(KURL,QCString)", "notifyRemove(KURL url,QCString saveId)" },
    { "ASYNC", "notifyRemove(KURL::List,QCString)", "notifyRemove(KURL::List url,QCString saveId)" },
    { "QStringList", "allURLs()", "allURLs()" },
    { 0, 0, 0 }
};
static const int KonqHistoryComm_ftable_hiddens[7] = {
    0,
    0,
    0,
    0,
    0,
    0,
    0,
};

bool KonqHistoryComm::process(const QCString &fun, const QByteArray &data, QCString& replyType, QByteArray &replyData)
{
    if ( fun == KonqHistoryComm_ftable[0][1] ) { // void notifyHistoryEntry(KonqHistoryEntry,QCString)
	KonqHistoryEntry arg0;
	QCString arg1;
	QDataStream arg( data, IO_ReadOnly );
	if (arg.atEnd()) return false;
	arg >> arg0;
	if (arg.atEnd()) return false;
	arg >> arg1;
	replyType = KonqHistoryComm_ftable[0][0]; 
	notifyHistoryEntry(arg0, arg1 );
    } else if ( fun == KonqHistoryComm_ftable[1][1] ) { // void notifyMaxCount(Q_UINT32,QCString)
	Q_UINT32 arg0;
	QCString arg1;
	QDataStream arg( data, IO_ReadOnly );
	if (arg.atEnd()) return false;
	arg >> arg0;
	if (arg.atEnd()) return false;
	arg >> arg1;
	replyType = KonqHistoryComm_ftable[1][0]; 
	notifyMaxCount(arg0, arg1 );
    } else if ( fun == KonqHistoryComm_ftable[2][1] ) { // void notifyMaxAge(Q_UINT32,QCString)
	Q_UINT32 arg0;
	QCString arg1;
	QDataStream arg( data, IO_ReadOnly );
	if (arg.atEnd()) return false;
	arg >> arg0;
	if (arg.atEnd()) return false;
	arg >> arg1;
	replyType = KonqHistoryComm_ftable[2][0]; 
	notifyMaxAge(arg0, arg1 );
    } else if ( fun == KonqHistoryComm_ftable[3][1] ) { // void notifyClear(QCString)
	QCString arg0;
	QDataStream arg( data, IO_ReadOnly );
	if (arg.atEnd()) return false;
	arg >> arg0;
	replyType = KonqHistoryComm_ftable[3][0]; 
	notifyClear(arg0 );
    } else if ( fun == KonqHistoryComm_ftable[4][1] ) { // void notifyRemove(KURL,QCString)
	KURL arg0;
	QCString arg1;
	QDataStream arg( data, IO_ReadOnly );
	if (arg.atEnd()) return false;
	arg >> arg0;
	if (arg.atEnd()) return false;
	arg >> arg1;
	replyType = KonqHistoryComm_ftable[4][0]; 
	notifyRemove(arg0, arg1 );
    } else if ( fun == KonqHistoryComm_ftable[5][1] ) { // void notifyRemove(KURL::List,QCString)
	KURL::List arg0;
	QCString arg1;
	QDataStream arg( data, IO_ReadOnly );
	if (arg.atEnd()) return false;
	arg >> arg0;
	if (arg.atEnd()) return false;
	arg >> arg1;
	replyType = KonqHistoryComm_ftable[5][0]; 
	notifyRemove(arg0, arg1 );
    } else if ( fun == KonqHistoryComm_ftable[6][1] ) { // QStringList allURLs()
	replyType = KonqHistoryComm_ftable[6][0]; 
	QDataStream _replyStream( replyData, IO_WriteOnly );
	_replyStream << allURLs( );
    } else {
	return DCOPObject::process( fun, data, replyType, replyData );
    }
    return true;
}

QCStringList KonqHistoryComm::interfaces()
{
    QCStringList ifaces = DCOPObject::interfaces();
    ifaces += "KonqHistoryComm";
    return ifaces;
}

QCStringList KonqHistoryComm::functions()
{
    QCStringList funcs = DCOPObject::functions();
    for ( int i = 0; KonqHistoryComm_ftable[i][2]; i++ ) {
	if (KonqHistoryComm_ftable_hiddens[i])
	    continue;
	QCString func = KonqHistoryComm_ftable[i][0];
	func += ' ';
	func += KonqHistoryComm_ftable[i][2];
	funcs << func;
    }
    return funcs;
}


