/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/performance/system_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef SYSTEM_UI_H
#define SYSTEM_UI_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QGroupBox;
class QCheckBox;
class QLabel;

class System_ui : public QWidget
{
    Q_OBJECT

public:
    System_ui( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~System_ui();

    QGroupBox* gb_;
    QCheckBox* cb_disable_kbuildsycoca;
    QLabel* label_kbuildsycoca;

protected:
    QVBoxLayout* System_uiLayout;
    QSpacerItem* spacer1;
    QVBoxLayout* gb_Layout;

protected slots:
    virtual void languageChange();

};

#endif // SYSTEM_UI_H
