#include <kdialog.h>
#include <klocale.h>
/****************************************************************************
** Form implementation generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/konqhtml/nsconfigwidget.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "nsconfigwidget.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qtabwidget.h>
#include <qcheckbox.h>
#include <qgroupbox.h>
#include <kurlrequester.h>
#include <klistbox.h>
#include <qheader.h>
#include <qlistview.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include "qwidget.h"
#include "kurlrequester.h"
#include "klineedit.h"
#include "kpushbutton.h"
#include "klistbox.h"
#include "kdialog.h"

/*
 *  Constructs a NSConfigWidget as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 */
NSConfigWidget::NSConfigWidget( QWidget* parent, const char* name, WFlags fl )
    : QWidget( parent, name, fl )
{
    if ( !name )
	setName( "NSConfigWidget" );
    NSConfigWidgetLayout = new QVBoxLayout( this, 0, 6, "NSConfigWidgetLayout"); 

    TabWidget2 = new QTabWidget( this, "TabWidget2" );

    tab = new QWidget( TabWidget2, "tab" );
    tabLayout = new QVBoxLayout( tab, KDialog::marginHint(), KDialog::spacingHint(), "tabLayout"); 

    Layout1 = new QHBoxLayout( 0, 0, KDialog::spacingHint(), "Layout1"); 

    scanButton = new QPushButton( tab, "scanButton" );
    Layout1->addWidget( scanButton );
    Spacer1_2 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    Layout1->addItem( Spacer1_2 );
    tabLayout->addLayout( Layout1 );

    scanAtStartup = new QCheckBox( tab, "scanAtStartup" );
    tabLayout->addWidget( scanAtStartup );

    GroupBox1 = new QGroupBox( tab, "GroupBox1" );
    GroupBox1->setMinimumSize( QSize( 300, 0 ) );
    GroupBox1->setColumnLayout(0, Qt::Vertical );
    GroupBox1->layout()->setSpacing( KDialog::spacingHint() );
    GroupBox1->layout()->setMargin( KDialog::marginHint() );
    GroupBox1Layout = new QGridLayout( GroupBox1->layout() );
    GroupBox1Layout->setAlignment( Qt::AlignTop );

    dirRemove = new QPushButton( GroupBox1, "dirRemove" );
    dirRemove->setEnabled( FALSE );

    GroupBox1Layout->addWidget( dirRemove, 1, 2 );

    dirNew = new QPushButton( GroupBox1, "dirNew" );

    GroupBox1Layout->addWidget( dirNew, 0, 2 );

    dirEdit = new KURLRequester( GroupBox1, "dirEdit" );
    dirEdit->setEnabled( FALSE );
    dirEdit->setProperty( "mode", 18 );

    GroupBox1Layout->addMultiCellWidget( dirEdit, 0, 0, 0, 1 );

    dirDown = new QPushButton( GroupBox1, "dirDown" );
    dirDown->setEnabled( FALSE );

    GroupBox1Layout->addWidget( dirDown, 3, 2 );

    dirUp = new QPushButton( GroupBox1, "dirUp" );
    dirUp->setEnabled( FALSE );

    GroupBox1Layout->addWidget( dirUp, 2, 2 );

    dirList = new KListBox( GroupBox1, "dirList" );
    dirList->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7, (QSizePolicy::SizeType)7, 0, 0, dirList->sizePolicy().hasHeightForWidth() ) );

    GroupBox1Layout->addMultiCellWidget( dirList, 1, 4, 0, 1 );
    Spacer3 = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
    GroupBox1Layout->addItem( Spacer3, 4, 2 );
    tabLayout->addWidget( GroupBox1 );
    TabWidget2->insertTab( tab, QString::fromLatin1("") );

    tab_2 = new QWidget( TabWidget2, "tab_2" );
    tabLayout_2 = new QGridLayout( tab_2, 1, 1, KDialog::marginHint(), KDialog::spacingHint(), "tabLayout_2"); 

    pluginList = new QListView( tab_2, "pluginList" );
    pluginList->addColumn( tr2i18n( "Information" ) );
    pluginList->addColumn( tr2i18n( "Value" ) );
    pluginList->setAllColumnsShowFocus( TRUE );

    tabLayout_2->addWidget( pluginList, 1, 0 );

    useArtsdsp = new QCheckBox( tab_2, "useArtsdsp" );
    useArtsdsp->setEnabled( TRUE );

    tabLayout_2->addWidget( useArtsdsp, 0, 0 );
    TabWidget2->insertTab( tab_2, QString::fromLatin1("") );
    NSConfigWidgetLayout->addWidget( TabWidget2 );
    languageChange();
    resize( QSize(458, 373).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );
}

/*
 *  Destroys the object and frees any allocated resources
 */
NSConfigWidget::~NSConfigWidget()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void NSConfigWidget::languageChange()
{
    setCaption( tr2i18n( "Netscape Plugin Config" ) );
    scanButton->setText( tr2i18n( "&Scan for New Plugins" ) );
    QWhatsThis::add( scanButton, tr2i18n( "Click here to scan for newly installed Netscape plugins now." ) );
    scanAtStartup->setText( tr2i18n( "Scan for new plugins at &KDE startup" ) );
    QWhatsThis::add( scanAtStartup, tr2i18n( "If this option is enabled, KDE will look for new Netscape plugins every time it starts up. This makes it easier for you if you often install new plugins, but it may also slow down KDE startup. You might want to disable this option, especially if you seldom install plugins." ) );
    GroupBox1->setTitle( tr2i18n( "Scan Folders" ) );
    dirRemove->setText( tr2i18n( "&Remove" ) );
    dirNew->setText( tr2i18n( "&New" ) );
    dirDown->setText( tr2i18n( "Do&wn" ) );
    dirUp->setText( tr2i18n( "&Up" ) );
    TabWidget2->changeTab( tab, tr2i18n( "Scan" ) );
    pluginList->header()->setLabel( 0, tr2i18n( "Information" ) );
    pluginList->header()->setLabel( 1, tr2i18n( "Value" ) );
    QWhatsThis::add( pluginList, tr2i18n( "Here you can see a list of the Netscape plugins KDE has found." ) );
    useArtsdsp->setText( tr2i18n( "Use a&rtsdsp to pipe plugin sound through aRts" ) );
    TabWidget2->changeTab( tab_2, tr2i18n( "Plugins" ) );
}

#include "nsconfigwidget.moc"
