#include <kdialog.h>
#include <klocale.h>
/****************************************************************************
** Form implementation generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/performance/system_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "system_ui.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qgroupbox.h>
#include <qcheckbox.h>
#include <qlabel.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>

/*
 *  Constructs a System_ui as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 */
System_ui::System_ui( QWidget* parent, const char* name, WFlags fl )
    : QWidget( parent, name, fl )
{
    if ( !name )
	setName( "System_ui" );
    System_uiLayout = new QVBoxLayout( this, KDialog::marginHint(), KDialog::spacingHint(), "System_uiLayout"); 

    gb_ = new QGroupBox( this, "gb_" );
    gb_->setColumnLayout(0, Qt::Vertical );
    gb_->layout()->setSpacing( KDialog::spacingHint() );
    gb_->layout()->setMargin( KDialog::marginHint() );
    gb_Layout = new QVBoxLayout( gb_->layout() );
    gb_Layout->setAlignment( Qt::AlignTop );

    cb_disable_kbuildsycoca = new QCheckBox( gb_, "cb_disable_kbuildsycoca" );
    gb_Layout->addWidget( cb_disable_kbuildsycoca );

    label_kbuildsycoca = new QLabel( gb_, "label_kbuildsycoca" );
    gb_Layout->addWidget( label_kbuildsycoca );
    System_uiLayout->addWidget( gb_ );
    spacer1 = new QSpacerItem( 20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding );
    System_uiLayout->addItem( spacer1 );
    languageChange();
    resize( QSize(600, 480).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );
}

/*
 *  Destroys the object and frees any allocated resources
 */
System_ui::~System_ui()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void System_ui::languageChange()
{
    gb_->setTitle( tr2i18n( "System Configuration" ) );
    cb_disable_kbuildsycoca->setText( tr2i18n( "Disable &system configuration startup check" ) );
    label_kbuildsycoca->setText( tr2i18n( "<b>WARNING:</b> This option may in rare cases lead to various problems. Consult the What's This? (Shift+F1) help for details." ) );
}

#include "system_ui.moc"
