#include <kdialog.h>
#include <klocale.h>
/****************************************************************************
** Form implementation generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/componentchooser/componentchooser_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "componentchooser_ui.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qgroupbox.h>
#include <qwidgetstack.h>
#include <qlabel.h>
#include <klistbox.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include "klistbox.h"
#include "kdialog.h"

/*
 *  Constructs a ComponentChooser_UI as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 */
ComponentChooser_UI::ComponentChooser_UI( QWidget* parent, const char* name, WFlags fl )
    : QWidget( parent, name, fl )
{
    if ( !name )
	setName( "ComponentChooser_UI" );
    setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)5, 0, 0, sizePolicy().hasHeightForWidth() ) );
    ComponentChooser_UILayout = new QGridLayout( this, 1, 1, 0, KDialog::spacingHint(), "ComponentChooser_UILayout"); 

    GroupBox1 = new QGroupBox( this, "GroupBox1" );
    GroupBox1->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)1, 1, 0, GroupBox1->sizePolicy().hasHeightForWidth() ) );
    GroupBox1->setColumnLayout(0, Qt::Vertical );
    GroupBox1->layout()->setSpacing( KDialog::spacingHint() );
    GroupBox1->layout()->setMargin( 11 );
    GroupBox1Layout = new QVBoxLayout( GroupBox1->layout() );
    GroupBox1Layout->setAlignment( Qt::AlignTop );

    configContainer = new QWidgetStack( GroupBox1, "configContainer" );
    GroupBox1Layout->addWidget( configContainer );

    ComponentChooser_UILayout->addWidget( GroupBox1, 1, 1 );

    GroupBox2 = new QGroupBox( this, "GroupBox2" );
    GroupBox2->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)1, 0, 0, GroupBox2->sizePolicy().hasHeightForWidth() ) );
    GroupBox2->setColumnLayout(0, Qt::Vertical );
    GroupBox2->layout()->setSpacing( KDialog::spacingHint() );
    GroupBox2->layout()->setMargin( 11 );
    GroupBox2Layout = new QVBoxLayout( GroupBox2->layout() );
    GroupBox2Layout->setAlignment( Qt::AlignTop );

    ComponentDescription = new QLabel( GroupBox2, "ComponentDescription" );
    ComponentDescription->setAlignment( int( QLabel::WordBreak | QLabel::AlignTop ) );
    GroupBox2Layout->addWidget( ComponentDescription );

    ComponentChooser_UILayout->addWidget( GroupBox2, 0, 1 );

    ServiceChooser = new KListBox( this, "ServiceChooser" );
    ServiceChooser->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)3, 1, 0, ServiceChooser->sizePolicy().hasHeightForWidth() ) );

    ComponentChooser_UILayout->addMultiCellWidget( ServiceChooser, 0, 1, 0, 0 );
    languageChange();
    resize( QSize(482, 451).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );
}

/*
 *  Destroys the object and frees any allocated resources
 */
ComponentChooser_UI::~ComponentChooser_UI()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void ComponentChooser_UI::languageChange()
{
    GroupBox1->setTitle( tr2i18n( "Default Component" ) );
    QWhatsThis::add( GroupBox1, tr2i18n( "Here you can change the component program. Components are programs that handle basic tasks, like the terminal emulator, the text editor and the email client. Different KDE applications sometimes need to invoke a console emulator, send a mail or display some text. To do so consistently, these applications always call the same components. You can choose here which programs these components are." ) );
    GroupBox2->setTitle( tr2i18n( "Component Description" ) );
    QWhatsThis::add( GroupBox2, tr2i18n( "Here you can read a small description of the currently selected component. To change the selected component, click on the list to the left. To change the component program,  please choose it below." ) );
    ComponentDescription->setText( QString::null );
    ServiceChooser->setCurrentItem( -1 );
    QWhatsThis::add( ServiceChooser, tr2i18n( "<qt>\n"
"<p>This list shows the configurable component types. Click the component you want to configure.</p>\n"
"<p>In this dialog you can change KDE default components. Components are programs that handle basic tasks, like the terminal emulator, the text editor and the email client. Different KDE applications sometimes need to invoke a console emulator, send a mail or display some text. To do so consistently, these applications always call the same components. Here you can select which programs these components are.</p>\n"
"</qt>" ) );
}

#include "componentchooser_ui.moc"
