/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/arts/hardwaretab.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef HARDWARETAB_H
#define HARDWARETAB_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QGroupBox;
class QLabel;
class QComboBox;
class QCheckBox;
class QSpinBox;
class QLineEdit;
class KURLRequester;

class hardwareTab : public QWidget
{
    Q_OBJECT

public:
    hardwareTab( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~hardwareTab();

    QGroupBox* groupBox4;
    QLabel* textLabel3_2;
    QComboBox* audioIO;
    QCheckBox* fullDuplex;
    QCheckBox* customOptions;
    QCheckBox* customDevice;
    QLabel* textLabel2;
    QComboBox* soundQuality;
    QCheckBox* customRate;
    QSpinBox* samplingRate;
    QLineEdit* addOptions;
    QLineEdit* deviceName;
    QGroupBox* groupBox3;
    QCheckBox* midiUseMapper;
    QLabel* textLabel4;
    QComboBox* midiDevice;
    KURLRequester* midiMapper;

protected:
    QVBoxLayout* hardwareTabLayout;
    QSpacerItem* spacer17;
    QGridLayout* groupBox4Layout;
    QHBoxLayout* layout57;
    QHBoxLayout* layout31;
    QHBoxLayout* layout4;
    QSpacerItem* spacer2;
    QSpacerItem* spacer3;
    QHBoxLayout* layout6;
    QSpacerItem* spacer4;
    QGridLayout* groupBox3Layout;

protected slots:
    virtual void languageChange();

};

#endif // HARDWARETAB_H
