/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/konsole/sessiondialog.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef SESSIONDIALOG_H
#define SESSIONDIALOG_H

#include <qvariant.h>
#include <qwidget.h>
#include <kcolorbutton.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QGroupBox;
class QComboBox;
class QLineEdit;
class QLabel;
class KIconButton;
class QListBox;
class QListBoxItem;
class QPushButton;
class KURLRequester;

class SessionDialog : public QWidget
{
    Q_OBJECT

public:
    SessionDialog( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~SessionDialog();

    QGroupBox* propertiesGroup;
    QComboBox* fontCombo;
    QLineEdit* termLine;
    QComboBox* keytabCombo;
    QLabel* TextLabel5;
    QComboBox* schemaCombo;
    QLabel* TextLabel7;
    QLabel* TextLabel8;
    QLabel* TextLabel6;
    KIconButton* previewIcon;
    QLabel* TextLabel4;
    QGroupBox* sessionGroup;
    QListBox* sessionList;
    QPushButton* saveButton;
    QPushButton* removeButton;
    QGroupBox* generalGroup;
    QLabel* TextLabel1;
    QLabel* TextLabel2;
    QLabel* TextLabel3;
    QLineEdit* nameLine;
    QLineEdit* executeLine;
    KURLRequester* directoryLine;

protected:
    QVBoxLayout* SessionDialogLayout;
    QGridLayout* layout8;
    QGridLayout* propertiesGroupLayout;
    QGridLayout* Layout29;
    QVBoxLayout* sessionGroupLayout;
    QGridLayout* Layout3;
    QSpacerItem* Spacer7;
    QHBoxLayout* generalGroupLayout;
    QHBoxLayout* layout6;
    QGridLayout* layout5;
    QVBoxLayout* layout4;

protected slots:
    virtual void languageChange();

};

#endif // SESSIONDIALOG_H
