/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/kio/cache_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef CACHEDLGUI_H
#define CACHEDLGUI_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QLabel;
class KIntNumInput;
class QPushButton;
class QCheckBox;
class QButtonGroup;
class QRadioButton;

class CacheDlgUI : public QWidget
{
    Q_OBJECT

public:
    CacheDlgUI( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~CacheDlgUI();

    QLabel* lbMaxCacheSize;
    KIntNumInput* sbMaxCacheSize;
    QPushButton* pbClearCache;
    QCheckBox* cbUseCache;
    QButtonGroup* bgCachePolicy;
    QRadioButton* rbVerifyCache;
    QRadioButton* rbCacheIfPossible;
    QRadioButton* rbOfflineMode;

protected:
    QGridLayout* CacheDlgUILayout;
    QSpacerItem* spacer1;
    QSpacerItem* spacer2;
    QVBoxLayout* bgCachePolicyLayout;

protected slots:
    virtual void languageChange();

};

#endif // CACHEDLGUI_H
