/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/css/cssconfig.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef CSSCONFIGDIALOG_H
#define CSSCONFIGDIALOG_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QButtonGroup;
class QRadioButton;
class KURLRequester;
class QPushButton;

class CSSConfigDialog : public QWidget
{
    Q_OBJECT

public:
    CSSConfigDialog( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~CSSConfigDialog();

    QButtonGroup* ButtonGroup1;
    QRadioButton* useDefault;
    QRadioButton* useUser;
    KURLRequester* urlRequester;
    QRadioButton* useAccess;
    QPushButton* customize;

protected:
    QVBoxLayout* CSSConfigDialogLayout;
    QSpacerItem* spacer11;
    QVBoxLayout* ButtonGroup1Layout;
    QHBoxLayout* layout3;
    QSpacerItem* spacer9_2;
    QHBoxLayout* layout2;
    QSpacerItem* spacer9;
    QSpacerItem* spacer3;

protected slots:
    virtual void languageChange();

};

#endif // CSSCONFIGDIALOG_H
