/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/kio/envvarproxy_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef ENVVARPROXYDLGUI_H
#define ENVVARPROXYDLGUI_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class KLineEdit;
class QLabel;
class QCheckBox;
class QPushButton;

class EnvVarProxyDlgUI : public QWidget
{
    Q_OBJECT

public:
    EnvVarProxyDlgUI( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~EnvVarProxyDlgUI();

    KLineEdit* leFtp;
    KLineEdit* leHttp;
    QLabel* lbFtp;
    QLabel* lbHttps;
    QCheckBox* cbShowValue;
    QPushButton* pbVerify;
    QPushButton* pbDetect;
    QLabel* lbHttp;
    KLineEdit* leHttps;
    KLineEdit* leNoProxy;
    QLabel* lbNoProxy;

protected:
    QGridLayout* EnvVarProxyDlgUILayout;

protected slots:
    virtual void languageChange();

};

#endif // ENVVARPROXYDLGUI_H
