#include <kdialog.h>
#include <klocale.h>
/****************************************************************************
** Form implementation generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/privacy/kcmprivacydialog.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "kcmprivacydialog.h"

#include <qvariant.h>
#include <klistview.h>
#include <ktextedit.h>
#include <qsplitter.h>
#include <qheader.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>

/*
 *  Constructs a KCMPrivacyDialog as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 */
KCMPrivacyDialog::KCMPrivacyDialog( QWidget* parent, const char* name, WFlags fl )
    : QWidget( parent, name, fl )
{
    if ( !name )
	setName( "KCMPrivacyDialog" );
    setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7, (QSizePolicy::SizeType)7, 0, 0, sizePolicy().hasHeightForWidth() ) );
    setSizeIncrement( QSize( 0, 0 ) );
    setBaseSize( QSize( 400, 550 ) );
    KCMPrivacyDialogLayout = new QVBoxLayout( this, 0, 6, "KCMPrivacyDialogLayout"); 

    splitter1 = new QSplitter( this, "splitter1" );
    splitter1->setOrientation( QSplitter::Vertical );

    privacyListView = new KListView( splitter1, "privacyListView" );
    privacyListView->setShowSortIndicator( FALSE );
    privacyListView->setResizeMode( KListView::AllColumns );
    privacyListView->setItemsMovable( FALSE );
    privacyListView->setAutoOpen( FALSE );

    statusTextEdit = new KTextEdit( splitter1, "statusTextEdit" );
    statusTextEdit->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)7, 0, 0, statusTextEdit->sizePolicy().hasHeightForWidth() ) );
    statusTextEdit->setMinimumSize( QSize( 0, 50 ) );
    statusTextEdit->setMaximumSize( QSize( 32767, 200 ) );
    statusTextEdit->setResizePolicy( KTextEdit::Manual );
    statusTextEdit->setReadOnly( TRUE );
    KCMPrivacyDialogLayout->addWidget( splitter1 );

    layout1 = new QHBoxLayout( 0, 0, 6, "layout1"); 

    selectAllButton = new QPushButton( this, "selectAllButton" );
    selectAllButton->setMinimumSize( QSize( 80, 0 ) );
    selectAllButton->setMaximumSize( QSize( 32767, 32767 ) );
    layout1->addWidget( selectAllButton );

    selectNoneButton = new QPushButton( this, "selectNoneButton" );
    selectNoneButton->setMinimumSize( QSize( 80, 0 ) );
    selectNoneButton->setMaximumSize( QSize( 32767, 32767 ) );
    layout1->addWidget( selectNoneButton );
    spacer1 = new QSpacerItem( 80, 20, QSizePolicy::Maximum, QSizePolicy::Minimum );
    layout1->addItem( spacer1 );

    cleanupButton = new QPushButton( this, "cleanupButton" );
    cleanupButton->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)0, 0, 0, cleanupButton->sizePolicy().hasHeightForWidth() ) );
    cleanupButton->setMaximumSize( QSize( 32767, 32767 ) );
    layout1->addWidget( cleanupButton );
    KCMPrivacyDialogLayout->addLayout( layout1 );
    languageChange();
    resize( QSize(452, 226).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );
}

/*
 *  Destroys the object and frees any allocated resources
 */
KCMPrivacyDialog::~KCMPrivacyDialog()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void KCMPrivacyDialog::languageChange()
{
    setCaption( tr2i18n( "Privacy" ) );
    statusTextEdit->setText( QString::null );
    selectAllButton->setText( tr2i18n( "Select All" ) );
    selectNoneButton->setText( tr2i18n( "Select None" ) );
    cleanupButton->setText( tr2i18n( "Clean Up" ) );
}

#include "kcmprivacydialog.moc"
