/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/konsole/kcmkonsoledialog.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef KCMKONSOLEDIALOG_H
#define KCMKONSOLEDIALOG_H

#include <qvariant.h>
#include <qwidget.h>
#include <kcolorbutton.h>
#include <knuminput.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class SchemaEditor;
class SessionEditor;
class QTabWidget;
class QGroupBox;
class QLabel;
class QLineEdit;
class QCheckBox;
class KIntNumInput;

class KCMKonsoleDialog : public QWidget
{
    Q_OBJECT

public:
    KCMKonsoleDialog( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~KCMKonsoleDialog();

    QTabWidget* TabWidget2;
    QWidget* tab;
    QGroupBox* GroupBox3;
    QLabel* TextLabel1_3;
    QLineEdit* word_connectorLE;
    QGroupBox* GroupBox2;
    QCheckBox* terminalSizeHintCB;
    QCheckBox* frameCB;
    QCheckBox* warnCB;
    QCheckBox* blinkingCB;
    QCheckBox* ctrldragCB;
    QCheckBox* cutToBeginningOfLineCB;
    QCheckBox* allowResizeCB;
    QCheckBox* xonXoffCB;
    QCheckBox* bidiCB;
    QLabel* SilenceLabel;
    KIntNumInput* silence_secondsSB;
    KIntNumInput* line_spacingSB;
    QLabel* TextLabel1_4;
    QCheckBox* matchTabWinTitleCB;
    QWidget* tab_2;
    SchemaEditor* SchemaEditor1;
    QWidget* tab_3;
    SessionEditor* SessionEditor1;

protected:
    QGridLayout* KCMKonsoleDialogLayout;
    QGridLayout* tabLayout;
    QSpacerItem* Spacer3;
    QGridLayout* GroupBox3Layout;
    QGridLayout* GroupBox2Layout;
    QSpacerItem* Spacer3_2;
    QSpacerItem* Spacer2;
    QVBoxLayout* tabLayout_2;
    QVBoxLayout* tabLayout_3;

protected slots:
    virtual void languageChange();

};

#endif // KCMKONSOLEDIALOG_H
