/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/performance/konqueror_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef KONQUEROR_UI_H
#define KONQUEROR_UI_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QButtonGroup;
class QRadioButton;
class QGroupBox;
class QLabel;
class QSpinBox;
class QCheckBox;

namespace KCMPerformance {
class Konqueror_ui : public QWidget
{
    Q_OBJECT

public:
    Konqueror_ui( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~Konqueror_ui();

    QButtonGroup* reuse_group;
    QRadioButton* rb_never_reuse;
    QRadioButton* rb_file_browsing_reuse;
    QRadioButton* rb_always_reuse;
    QGroupBox* groupBox1;
    QLabel* lb_preload_count;
    QSpinBox* sb_preload_count;
    QCheckBox* cb_preload_on_startup;
    QCheckBox* cb_always_have_preloaded;

protected:
    QVBoxLayout* Konqueror_uiLayout;
    QSpacerItem* spacer1;
    QVBoxLayout* reuse_groupLayout;
    QVBoxLayout* groupBox1Layout;
    QHBoxLayout* layout2;
    QSpacerItem* spacer2;

protected slots:
    virtual void languageChange();

};
}

#endif // KONQUEROR_UI_H
