#include <kdialog.h>
#include <klocale.h>
/****************************************************************************
** Form implementation generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/kio/envvarproxy_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "envvarproxy_ui.h"

#include <qvariant.h>
#include <klineedit.h>
#include <qlabel.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>

/*
 *  Constructs a EnvVarProxyDlgUI as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 */
EnvVarProxyDlgUI::EnvVarProxyDlgUI( QWidget* parent, const char* name, WFlags fl )
    : QWidget( parent, name, fl )
{
    if ( !name )
	setName( "EnvVarProxyDlgUI" );
    EnvVarProxyDlgUILayout = new QGridLayout( this, 1, 1, 0, 6, "EnvVarProxyDlgUILayout"); 

    leFtp = new KLineEdit( this, "leFtp" );

    EnvVarProxyDlgUILayout->addWidget( leFtp, 2, 1 );

    leHttp = new KLineEdit( this, "leHttp" );

    EnvVarProxyDlgUILayout->addWidget( leHttp, 0, 1 );

    lbFtp = new QLabel( this, "lbFtp" );

    EnvVarProxyDlgUILayout->addWidget( lbFtp, 2, 0 );

    lbHttps = new QLabel( this, "lbHttps" );

    EnvVarProxyDlgUILayout->addWidget( lbHttps, 1, 0 );

    cbShowValue = new QCheckBox( this, "cbShowValue" );

    EnvVarProxyDlgUILayout->addWidget( cbShowValue, 4, 1 );

    pbVerify = new QPushButton( this, "pbVerify" );

    EnvVarProxyDlgUILayout->addWidget( pbVerify, 0, 2 );

    pbDetect = new QPushButton( this, "pbDetect" );

    EnvVarProxyDlgUILayout->addWidget( pbDetect, 1, 2 );

    lbHttp = new QLabel( this, "lbHttp" );

    EnvVarProxyDlgUILayout->addWidget( lbHttp, 0, 0 );

    leHttps = new KLineEdit( this, "leHttps" );

    EnvVarProxyDlgUILayout->addWidget( leHttps, 1, 1 );

    leNoProxy = new KLineEdit( this, "leNoProxy" );

    EnvVarProxyDlgUILayout->addWidget( leNoProxy, 3, 1 );

    lbNoProxy = new QLabel( this, "lbNoProxy" );

    EnvVarProxyDlgUILayout->addWidget( lbNoProxy, 3, 0 );
    languageChange();
    resize( QSize(438, 133).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );

    // tab order
    setTabOrder( leHttp, leHttps );
    setTabOrder( leHttps, leFtp );
    setTabOrder( leFtp, leNoProxy );
    setTabOrder( leNoProxy, pbVerify );
    setTabOrder( pbVerify, pbDetect );

    // buddies
    lbFtp->setBuddy( leFtp );
    lbHttps->setBuddy( leHttps );
    lbHttp->setBuddy( leHttp );
    lbNoProxy->setBuddy( leNoProxy );
}

/*
 *  Destroys the object and frees any allocated resources
 */
EnvVarProxyDlgUI::~EnvVarProxyDlgUI()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void EnvVarProxyDlgUI::languageChange()
{
    QWhatsThis::add( leFtp, tr2i18n( "<qt>\n"
"Enter the name of the environment variable, e.g. <b>FTP_PROXY</b>, used to store the address of the FTP proxy server.<p>\n"
"Alternatively, you can click on the <b>\"Auto Detect\"</b> button to attempt an automatic discovery of this variable.\n"
"</qt>" ) );
    QWhatsThis::add( leHttp, tr2i18n( "<qt>\n"
"Enter the name of the environment variable, e.g. <b>HTTP_PROXY</b>, used to store the address of the HTTP proxy server.<p>\n"
"Alternatively, you can click on the <b>\"Auto Detect\"</b> button to attempt automatic discovery of this variable.\n"
"</qt>" ) );
    lbFtp->setText( tr2i18n( "&FTP:" ) );
    QWhatsThis::add( lbFtp, tr2i18n( "<qt>\n"
"Enter the name of the environment variable, e.g. <b>FTP_PROXY</b>, used to store the address of the FTP proxy server.<p>\n"
"Alternatively, you can click on the <b>\"Auto Detect\"</b> button to attempt an automatic discovery of this variable.\n"
"</qt>" ) );
    lbHttps->setText( tr2i18n( "HTTP&S:" ) );
    QWhatsThis::add( lbHttps, tr2i18n( "<qt>\n"
"Enter the name of the environment variable, e.g. <b>HTTPS_PROXY</b>, used to store the address of the HTTPS proxy server.<p>\n"
"Alternatively, you can click on the <b>\"Auto Detect\"</b> button to attempt an automatic discovery of this variable.\n"
"</qt>" ) );
    cbShowValue->setText( tr2i18n( "Show the &value of the environment variables" ) );
    pbVerify->setText( tr2i18n( "&Verify" ) );
    QWhatsThis::add( pbVerify, tr2i18n( "<qt>Verify whether or not the environment variable names you supplied are valid. If an environment variable is not found, the associated labels will be <b>highlighted</b> to indicate that they are invalid.</qt>" ) );
    pbDetect->setText( tr2i18n( "Auto &Detect" ) );
    QWhatsThis::add( pbDetect, tr2i18n( "<qt>Attempt automatic discovery of the environment variables used for setting system wide proxy information.<p> This feature works by searching for commonly used variable names such as HTTP_PROXY, FTP_PROXY and NO_PROXY.</qt>" ) );
    lbHttp->setText( tr2i18n( "H&TTP:" ) );
    QWhatsThis::add( lbHttp, tr2i18n( "<qt>\n"
"Enter the name of the environment variable, e.g. <b>HTTP_PROXY</b>, used to store the address of the HTTP proxy server.<p>\n"
"Alternatively, you can click on the <b>\"Auto Detect\"</b> button to attempt automatic discovery of this variable.\n"
"</qt>" ) );
    QWhatsThis::add( leHttps, tr2i18n( "<qt>\n"
"Enter the name of the environment variable, e.g. <b>HTTPS_PROXY</b>, used to store the address of the HTTPS proxy server.<p>\n"
"Alternatively, you can click on the <b>\"Auto Detect\"</b> button to attempt an automatic discovery of this variable.\n"
"</qt>" ) );
    QWhatsThis::add( leNoProxy, tr2i18n( "<qt>\n"
"Enter the environment variable, e.g. <b>NO_PROXY</b>, used to store the addresses of sites for which the proxy server should not be used.<p>\n"
"Alternatively, you can click on the <b>\"Auto Detect\"</b> button to attempt an automatic discovery of this variable.\n"
"</qt>" ) );
    lbNoProxy->setText( tr2i18n( "NO &PROXY:" ) );
    QWhatsThis::add( lbNoProxy, tr2i18n( "<qt>\n"
"Enter the environment variable, e.g. <b>NO_PROXY</b>, used to store the addresses of sites for which the proxy server should not be used.<p>\n"
"Alternatively, you can click on the <b>\"Auto Detect\"</b> button to attempt an automatic discovery of this variable.\n"
"</qt>" ) );
}

#include "envvarproxy_ui.moc"
