/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/css/csscustom.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef CSSCUSTOMDIALOG_H
#define CSSCUSTOMDIALOG_H

#include <qvariant.h>
#include <qwidget.h>
#include <kcolorbutton.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QGroupBox;
class QComboBox;
class QLabel;
class QCheckBox;
class QPushButton;
class QButtonGroup;
class QRadioButton;
class KColorButton;

class CSSCustomDialog : public QWidget
{
    Q_OBJECT

public:
    CSSCustomDialog( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~CSSCustomDialog();

    QGroupBox* GroupBox3;
    QComboBox* basefontsize;
    QLabel* txtFontsize;
    QCheckBox* dontScale;
    QGroupBox* GroupBox3_2;
    QCheckBox* hideImages;
    QCheckBox* hideBackground;
    QGroupBox* GroupBox7;
    QLabel* txtBaseFontFamily;
    QComboBox* fontFamily;
    QCheckBox* sameFamily;
    QPushButton* preview;
    QButtonGroup* ButtonGroup2;
    QRadioButton* blackOnWhite;
    QRadioButton* whiteOnBlack;
    QRadioButton* customColor;
    KColorButton* foregroundColor;
    QLabel* txtForeground;
    KColorButton* backgroundColor;
    QLabel* txtBackground;
    QCheckBox* sameColor;

protected:
    QGridLayout* CSSCustomDialogLayout;
    QSpacerItem* Spacer5_2;
    QGridLayout* GroupBox3Layout;
    QGridLayout* GroupBox3_2Layout;
    QGridLayout* GroupBox7Layout;
    QSpacerItem* Spacer7;
    QHBoxLayout* Layout1;
    QSpacerItem* Spacer1_4;
    QVBoxLayout* ButtonGroup2Layout;
    QGridLayout* Layout2;
    QSpacerItem* Spacer9;
    QSpacerItem* Spacer1;
    QSpacerItem* Spacer1_2;
    QSpacerItem* Spacer8;

protected slots:
    virtual void languageChange();

};

#endif // CSSCUSTOMDIALOG_H
