#include <kdialog.h>
#include <klocale.h>
/****************************************************************************
** Form implementation generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/componentchooser/componentconfig_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "componentconfig_ui.h"

#include <qvariant.h>
#include <qlabel.h>
#include <kcombobox.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include "kdialog.h"

/*
 *  Constructs a ComponentConfig_UI as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 */
ComponentConfig_UI::ComponentConfig_UI( QWidget* parent, const char* name, WFlags fl )
    : QWidget( parent, name, fl )
{
    if ( !name )
	setName( "ComponentConfig_UI" );
    setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)3, (QSizePolicy::SizeType)3, 0, 0, sizePolicy().hasHeightForWidth() ) );
    ComponentConfig_UILayout = new QVBoxLayout( this, 0, KDialog::spacingHint(), "ComponentConfig_UILayout"); 

    ChooserDocu = new QLabel( this, "ChooserDocu" );
    ChooserDocu->setAlignment( int( QLabel::WordBreak | QLabel::AlignVCenter ) );
    ComponentConfig_UILayout->addWidget( ChooserDocu );

    ComponentSelector = new KComboBox( FALSE, this, "ComponentSelector" );
    ComponentConfig_UILayout->addWidget( ComponentSelector );
    Spacer2 = new QSpacerItem( 0, 91, QSizePolicy::Minimum, QSizePolicy::Expanding );
    ComponentConfig_UILayout->addItem( Spacer2 );
    languageChange();
}

/*
 *  Destroys the object and frees any allocated resources
 */
ComponentConfig_UI::~ComponentConfig_UI()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void ComponentConfig_UI::languageChange()
{
    ChooserDocu->setText( QString::null );
}

#include "componentconfig_ui.moc"
