/****************************************************************************
**
** DCOP Skeleton generated by dcopidl2cpp from main.kidl
**
** WARNING! All changes made in this file will be lost!
**
*****************************************************************************/

#include "/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcminit/main.h"

#include <kdatastream.h>


static const char* const KCMInit_ftable[3][3] = {
    { "void", "runPhase1()", "runPhase1()" },
    { "void", "runPhase2()", "runPhase2()" },
    { 0, 0, 0 }
};
static const int KCMInit_ftable_hiddens[2] = {
    0,
    0,
};

bool KCMInit::process(const QCString &fun, const QByteArray &data, QCString& replyType, QByteArray &replyData)
{
    if ( fun == KCMInit_ftable[0][1] ) { // void runPhase1()
	replyType = KCMInit_ftable[0][0]; 
	runPhase1( );
    } else if ( fun == KCMInit_ftable[1][1] ) { // void runPhase2()
	replyType = KCMInit_ftable[1][0]; 
	runPhase2( );
    } else {
	return DCOPObject::process( fun, data, replyType, replyData );
    }
    return true;
}

QCStringList KCMInit::interfaces()
{
    QCStringList ifaces = DCOPObject::interfaces();
    ifaces += "KCMInit";
    return ifaces;
}

QCStringList KCMInit::functions()
{
    QCStringList funcs = DCOPObject::functions();
    for ( int i = 0; KCMInit_ftable[i][2]; i++ ) {
	if (KCMInit_ftable_hiddens[i])
	    continue;
	QCString func = KCMInit_ftable[i][0];
	func += ' ';
	func += KCMInit_ftable[i][2];
	funcs << func;
    }
    return funcs;
}


