/****************************************************************************
**
** DCOP Skeleton generated by dcopidl2cpp from remotedirnotify.kidl
**
** WARNING! All changes made in this file will be lost!
**
*****************************************************************************/

#include "/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kioslave/remote/kdedmodule/remotedirnotify.h"

#include <kdatastream.h>


static const char* const RemoteDirNotify_ftable[4][3] = {
    { "ASYNC", "FilesAdded(KURL)", "FilesAdded(KURL directory)" },
    { "ASYNC", "FilesRemoved(KURL::List)", "FilesRemoved(KURL::List fileList)" },
    { "ASYNC", "FilesChanged(KURL::List)", "FilesChanged(KURL::List fileList)" },
    { 0, 0, 0 }
};
static const int RemoteDirNotify_ftable_hiddens[3] = {
    0,
    0,
    0,
};

bool RemoteDirNotify::process(const QCString &fun, const QByteArray &data, QCString& replyType, QByteArray &replyData)
{
    if ( fun == RemoteDirNotify_ftable[0][1] ) { // void FilesAdded(KURL)
	KURL arg0;
	QDataStream arg( data, IO_ReadOnly );
	if (arg.atEnd()) return false;
	arg >> arg0;
	replyType = RemoteDirNotify_ftable[0][0]; 
	FilesAdded(arg0 );
    } else if ( fun == RemoteDirNotify_ftable[1][1] ) { // void FilesRemoved(KURL::List)
	KURL::List arg0;
	QDataStream arg( data, IO_ReadOnly );
	if (arg.atEnd()) return false;
	arg >> arg0;
	replyType = RemoteDirNotify_ftable[1][0]; 
	FilesRemoved(arg0 );
    } else if ( fun == RemoteDirNotify_ftable[2][1] ) { // void FilesChanged(KURL::List)
	KURL::List arg0;
	QDataStream arg( data, IO_ReadOnly );
	if (arg.atEnd()) return false;
	arg >> arg0;
	replyType = RemoteDirNotify_ftable[2][0]; 
	FilesChanged(arg0 );
    } else {
	return KDirNotify::process( fun, data, replyType, replyData );
    }
    return true;
}

QCStringList RemoteDirNotify::interfaces()
{
    QCStringList ifaces = KDirNotify::interfaces();
    ifaces += "RemoteDirNotify";
    return ifaces;
}

QCStringList RemoteDirNotify::functions()
{
    QCStringList funcs = KDirNotify::functions();
    for ( int i = 0; RemoteDirNotify_ftable[i][2]; i++ ) {
	if (RemoteDirNotify_ftable_hiddens[i])
	    continue;
	QCString func = RemoteDirNotify_ftable[i][0];
	func += ' ';
	func += RemoteDirNotify_ftable[i][2];
	funcs << func;
    }
    return funcs;
}


