// This file is generated by kconfig_compiler from mediamanagersettings.kcfg.
// All changes you do to this file will be lost.

#include "mediamanagersettings.h"

#include <kstaticdeleter.h>

MediaManagerSettings *MediaManagerSettings::mSelf = 0;
static KStaticDeleter<MediaManagerSettings> staticMediaManagerSettingsDeleter;

MediaManagerSettings *MediaManagerSettings::self()
{
  if ( !mSelf ) {
    staticMediaManagerSettingsDeleter.setObject( mSelf, new MediaManagerSettings() );
    mSelf->readConfig();
  }

  return mSelf;
}

MediaManagerSettings::MediaManagerSettings(  )
  : KConfigSkeleton( QString::fromLatin1( "mediamanagerrc" ) )
{
  mSelf = this;
  setCurrentGroup( QString::fromLatin1( "Global" ) );

  KConfigSkeleton::ItemBool  *itemHalBackendEnabled;
  itemHalBackendEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QString::fromLatin1( "HalBackendEnabled" ), mHalBackendEnabled, true );
  addItem( itemHalBackendEnabled, QString::fromLatin1( "HalBackendEnabled" ) );
  KConfigSkeleton::ItemBool  *itemCdPollingEnabled;
  itemCdPollingEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QString::fromLatin1( "CdPollingEnabled" ), mCdPollingEnabled, true );
  addItem( itemCdPollingEnabled, QString::fromLatin1( "CdPollingEnabled" ) );
  KConfigSkeleton::ItemBool  *itemAutostartEnabled;
  itemAutostartEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QString::fromLatin1( "AutostartEnabled" ), mAutostartEnabled, true );
  addItem( itemAutostartEnabled, QString::fromLatin1( "AutostartEnabled" ) );
}

MediaManagerSettings::~MediaManagerSettings()
{
  if ( mSelf == this )
    staticMediaManagerSettingsDeleter.setObject( mSelf, 0, false );
}

