#include <kdialog.h>
#include <klocale.h>
/****************************************************************************
** Form implementation generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/konqhtml/advancedTabOptions.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "advancedTabOptions.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qframe.h>
#include <qcheckbox.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include "kdialog.h"

/*
 *  Constructs a advancedTabOptions as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 */
advancedTabOptions::advancedTabOptions( QWidget* parent, const char* name, WFlags fl )
    : QWidget( parent, name, fl )
{
    if ( !name )
	setName( "advancedTabOptions" );
    advancedTabOptionsLayout = new QVBoxLayout( this, 0, KDialog::spacingHint(), "advancedTabOptionsLayout"); 

    TextLabel3 = new QLabel( this, "TextLabel3" );
    advancedTabOptionsLayout->addWidget( TextLabel3 );

    Line1 = new QFrame( this, "Line1" );
    Line1->setFrameShape( QFrame::HLine );
    Line1->setFrameShadow( QFrame::Sunken );
    Line1->setFrameShape( QFrame::HLine );
    advancedTabOptionsLayout->addWidget( Line1 );

    layout = new QVBoxLayout( 0, 0, KDialog::spacingHint(), "layout"); 

    m_pNewTabsInBackground = new QCheckBox( this, "m_pNewTabsInBackground" );
    layout->addWidget( m_pNewTabsInBackground );

    m_pOpenAfterCurrentPage = new QCheckBox( this, "m_pOpenAfterCurrentPage" );
    layout->addWidget( m_pOpenAfterCurrentPage );

    m_pTabConfirm = new QCheckBox( this, "m_pTabConfirm" );
    layout->addWidget( m_pTabConfirm );

    m_pPermanentCloseButton = new QCheckBox( this, "m_pPermanentCloseButton" );
    layout->addWidget( m_pPermanentCloseButton );

    m_pPopupsWithinTabs = new QCheckBox( this, "m_pPopupsWithinTabs" );
    layout->addWidget( m_pPopupsWithinTabs );

    m_pTabCloseActivatePrevious = new QCheckBox( this, "m_pTabCloseActivatePrevious" );
    layout->addWidget( m_pTabCloseActivatePrevious );

    m_pKonquerorTabforExternalURL = new QCheckBox( this, "m_pKonquerorTabforExternalURL" );
    layout->addWidget( m_pKonquerorTabforExternalURL );
    advancedTabOptionsLayout->addLayout( layout );
    spacer = new QSpacerItem( 20, 0, QSizePolicy::Minimum, QSizePolicy::Expanding );
    advancedTabOptionsLayout->addItem( spacer );
    languageChange();
    resize( QSize(644, 208).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );
}

/*
 *  Destroys the object and frees any allocated resources
 */
advancedTabOptions::~advancedTabOptions()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void advancedTabOptions::languageChange()
{
    TextLabel3->setText( tr2i18n( "<b>Advanced Options</b>" ) );
    m_pNewTabsInBackground->setText( tr2i18n( "O&pen new tabs in the background" ) );
    QWhatsThis::add( m_pNewTabsInBackground, tr2i18n( "This will open a new tab in the background, instead of in the foreground." ) );
    m_pOpenAfterCurrentPage->setText( tr2i18n( "Open &new tab after current tab" ) );
    QWhatsThis::add( m_pOpenAfterCurrentPage, tr2i18n( "This will open a new tab opened from a page after the current tab, instead of after the last tab." ) );
    m_pTabConfirm->setText( tr2i18n( "Confirm &when closing windows with multiple tabs" ) );
    QWhatsThis::add( m_pTabConfirm, tr2i18n( "This will ask you whether you are sure you want to close a window when it has multiple tabs opened in it." ) );
    m_pPermanentCloseButton->setText( tr2i18n( "&Show close button instead of website icon" ) );
    QWhatsThis::add( m_pPermanentCloseButton, tr2i18n( "This will display close buttons inside each tab instead of websites' icons." ) );
    m_pPopupsWithinTabs->setText( tr2i18n( "Open pop&ups in new tab instead of in new window" ) );
    QWhatsThis::add( m_pPopupsWithinTabs, tr2i18n( "Whether or not JavaScript popups if allowed shall open in a new tab or in a new window." ) );
    m_pTabCloseActivatePrevious->setText( tr2i18n( "Activate previous used tab when closing the current tab" ) );
    QWhatsThis::add( m_pTabCloseActivatePrevious, tr2i18n( "When checking this the previous used or opened tab will be activated when you close the current active tab instead of the one right to the current tab." ) );
    m_pKonquerorTabforExternalURL->setText( tr2i18n( "Open as tab in existing Konqueror when URL is called externally" ) );
    QWhatsThis::add( m_pKonquerorTabforExternalURL, tr2i18n( "When you click a URL in another KDE program or call kfmclient to open a URL, the current desktop will be searched for a non-minimized Konqueror and, if found, the URL opened as a new tab within it. Otherwise a new Konqueror window will be opened with the required URL." ) );
}

#include "advancedTabOptions.moc"
