/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kdcop/kdcopview.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef KDCOPVIEW_H
#define KDCOPVIEW_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class KDCOPListView;
class KListViewSearchLine;
class QLabel;
class QSplitter;
class KListBox;
class QListBoxItem;

class kdcopview : public QWidget
{
    Q_OBJECT

public:
    kdcopview( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~kdcopview();

    KListViewSearchLine* kListViewSearchLine1;
    QLabel* textLabel1;
    QSplitter* splitter8;
    KDCOPListView* lv;
    QLabel* l_replyType;
    KListBox* lb_replyData;
    QLabel* TextLabel1;

protected:
    QGridLayout* kdcopviewLayout;
    QGridLayout* layout18;

protected slots:
    virtual void languageChange();

private:
    QPixmap image0;

};

#endif // KDCOPVIEW_H
