/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/kio/kcookiespoliciesdlg_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef KCOOKIESPOLICYDLGUI_H
#define KCOOKIESPOLICYDLGUI_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QCheckBox;
class QGroupBox;
class QButtonGroup;
class QRadioButton;
class QPushButton;
class KListView;
class QListViewItem;
class QToolButton;
class QLabel;
class KListViewSearchLine;

class KCookiesPolicyDlgUI : public QWidget
{
    Q_OBJECT

public:
    KCookiesPolicyDlgUI( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~KCookiesPolicyDlgUI();

    QCheckBox* cbEnableCookies;
    QGroupBox* bgPreferences;
    QCheckBox* cbRejectCrossDomainCookies;
    QCheckBox* cbAutoAcceptSessionCookies;
    QCheckBox* cbIgnoreCookieExpirationDate;
    QButtonGroup* bgDefault;
    QRadioButton* rbPolicyAsk;
    QRadioButton* rbPolicyAccept;
    QRadioButton* rbPolicyReject;
    QGroupBox* gbDomainSpecific;
    QPushButton* pbNew;
    QPushButton* pbChange;
    QPushButton* pbDelete;
    QPushButton* pbDeleteAll;
    KListView* lvDomainPolicy;
    QToolButton* tbClearSearchLine;
    QLabel* textLabel1;
    KListViewSearchLine* kListViewSearchLine;

protected:
    QGridLayout* KCookiesPolicyDlgUILayout;
    QVBoxLayout* bgPreferencesLayout;
    QVBoxLayout* bgDefaultLayout;
    QGridLayout* gbDomainSpecificLayout;
    QSpacerItem* spacer1;
    QVBoxLayout* layout3;
    QHBoxLayout* layout2;

protected slots:
    virtual void languageChange();

};

#endif // KCOOKIESPOLICYDLGUI_H
