/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/kio/useragentdlg_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef USERAGENTDLGUI_H
#define USERAGENTDLGUI_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QCheckBox;
class QButtonGroup;
class KLineEdit;
class QGroupBox;
class KListView;
class QListViewItem;
class QPushButton;

class UserAgentDlgUI : public QWidget
{
    Q_OBJECT

public:
    UserAgentDlgUI( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~UserAgentDlgUI();

    QCheckBox* cbSendUAString;
    QButtonGroup* gbDefaultId;
    KLineEdit* leDefaultId;
    QCheckBox* cbOS;
    QCheckBox* cbOSVersion;
    QCheckBox* cbPlatform;
    QCheckBox* cbProcessorType;
    QCheckBox* cbLanguage;
    QGroupBox* gbDomainPolicy;
    KListView* lvDomainPolicyList;
    QPushButton* pbNew;
    QPushButton* pbChange;
    QPushButton* pbDelete;
    QPushButton* pbDeleteAll;

protected:
    QVBoxLayout* UserAgentDlgUILayout;
    QVBoxLayout* gbDefaultIdLayout;
    QHBoxLayout* layout2;
    QSpacerItem* spacer2;
    QHBoxLayout* gbDomainPolicyLayout;
    QVBoxLayout* layout1;
    QSpacerItem* spacer1;

protected slots:
    virtual void languageChange();

};

#endif // USERAGENTDLGUI_H
