/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/knotify/playersettings.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef PLAYERSETTINGSUI_H
#define PLAYERSETTINGSUI_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QLabel;
class QFrame;
class QButtonGroup;
class QRadioButton;
class QSlider;
class KURLRequester;

class PlayerSettingsUI : public QWidget
{
    Q_OBJECT

public:
    PlayerSettingsUI( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~PlayerSettingsUI();

    QLabel* textLabel1;
    QFrame* line1;
    QButtonGroup* grpPlayers;
    QRadioButton* cbNone;
    QRadioButton* cbExternal;
    QLabel* textLabel3;
    QLabel* textLabel2;
    QSlider* volumeSlider;
    QLabel* textLabel4;
    QRadioButton* cbArts;
    QLabel* textLabel5;
    KURLRequester* reqExternal;

protected:
    QVBoxLayout* PlayerSettingsUILayout;
    QSpacerItem* spacer5;
    QGridLayout* grpPlayersLayout;
    QSpacerItem* spacer2;
    QSpacerItem* spacer3;
    QGridLayout* layout5;
    QSpacerItem* spacer4;
    QGridLayout* layout4;
    QSpacerItem* spacer1;

protected slots:
    virtual void languageChange();

};

#endif // PLAYERSETTINGSUI_H
