/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/konq/desktopbehavior.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef DESKTOPBEHAVIORBASE_H
#define DESKTOPBEHAVIORBASE_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QTabWidget;
class QCheckBox;
class QButtonGroup;
class QRadioButton;
class QGroupBox;
class QLabel;
class QComboBox;
class QPushButton;
class KListView;
class QListViewItem;

class DesktopBehaviorBase : public QWidget
{
    Q_OBJECT

public:
    DesktopBehaviorBase( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~DesktopBehaviorBase();

    QTabWidget* behaviorTab;
    QWidget* tab;
    QCheckBox* iconsEnabledBox;
    QCheckBox* vrootBox;
    QCheckBox* toolTipBox;
    QButtonGroup* desktopMenuGroup;
    QRadioButton* radioButton1;
    QRadioButton* radioButton1_2;
    QRadioButton* radioButton1_3;
    QGroupBox* groupBox3;
    QLabel* middleLabel;
    QLabel* leftLabel;
    QLabel* rightLabel;
    QComboBox* rightComboBox;
    QComboBox* leftComboBox;
    QPushButton* leftEditButton;
    QComboBox* middleComboBox;
    QPushButton* middleEditButton;
    QPushButton* rightEditButton;
    QWidget* tab_2;
    QCheckBox* autoLineupIconsBox;
    QCheckBox* showHiddenBox;
    KListView* previewListView;
    QWidget* tab_3;
    QCheckBox* enableMediaBox;
    KListView* mediaListView;

protected:
    QVBoxLayout* DesktopBehaviorBaseLayout;
    QGridLayout* tabLayout;
    QSpacerItem* spacer8;
    QHBoxLayout* layout1;
    QSpacerItem* spacer3;
    QVBoxLayout* desktopMenuGroupLayout;
    QGridLayout* groupBox3Layout;
    QSpacerItem* spacer5;
    QGridLayout* tabLayout_2;
    QVBoxLayout* tabLayout_3;

protected slots:
    virtual void languageChange();

};

#endif // DESKTOPBEHAVIORBASE_H
