/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/konqhtml/nsconfigwidget.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef NSCONFIGWIDGET_H
#define NSCONFIGWIDGET_H

#include <qvariant.h>
#include <qwidget.h>
#include <klocale.h>
#include <kurlrequester.h>
#include <klistbox.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QTabWidget;
class QPushButton;
class QCheckBox;
class QGroupBox;
class KURLRequester;
class KListBox;
class QListBoxItem;
class QListView;
class QListViewItem;

class NSConfigWidget : public QWidget
{
    Q_OBJECT

public:
    NSConfigWidget( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~NSConfigWidget();

    QTabWidget* TabWidget2;
    QWidget* tab;
    QPushButton* scanButton;
    QCheckBox* scanAtStartup;
    QGroupBox* GroupBox1;
    QPushButton* dirRemove;
    QPushButton* dirNew;
    KURLRequester* dirEdit;
    QPushButton* dirDown;
    QPushButton* dirUp;
    KListBox* dirList;
    QWidget* tab_2;
    QListView* pluginList;
    QCheckBox* useArtsdsp;

protected:
    QVBoxLayout* NSConfigWidgetLayout;
    QVBoxLayout* tabLayout;
    QHBoxLayout* Layout1;
    QSpacerItem* Spacer1_2;
    QGridLayout* GroupBox1Layout;
    QSpacerItem* Spacer3;
    QGridLayout* tabLayout_2;

protected slots:
    virtual void languageChange();

};

#endif // NSCONFIGWIDGET_H
