/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/kio/socksbase.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef SOCKSBASE_H
#define SOCKSBASE_H

#include <qvariant.h>
#include <qwidget.h>
#include <kurlrequester.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QCheckBox;
class QButtonGroup;
class QRadioButton;
class QLabel;
class KURLRequester;
class QGroupBox;
class QListView;
class QListViewItem;
class QPushButton;

class SocksBase : public QWidget
{
    Q_OBJECT

public:
    SocksBase( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~SocksBase();

    QCheckBox* _c_enableSocks;
    QButtonGroup* bg;
    QRadioButton* _c_detect;
    QRadioButton* _c_NEC;
    QRadioButton* _c_custom;
    QLabel* _c_customLabel;
    KURLRequester* _c_customPath;
    QRadioButton* _c_Dante;
    QGroupBox* _c_addPaths;
    QListView* _c_libs;
    KURLRequester* _c_newPath;
    QPushButton* _c_add;
    QPushButton* _c_remove;
    QPushButton* _c_test;

protected:
    QVBoxLayout* SocksBaseLayout;
    QGridLayout* bgLayout;
    QHBoxLayout* Layout6;
    QVBoxLayout* _c_addPathsLayout;
    QHBoxLayout* Layout1;
    QSpacerItem* Spacer1;
    QHBoxLayout* Layout2;
    QSpacerItem* Spacer2;

protected slots:
    virtual void languageChange();

};

#endif // SOCKSBASE_H
