#include <kdialog.h>
#include <klocale.h>
/****************************************************************************
** Form implementation generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kdcop/kdcopview.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "kdcopview.h"

#include <qvariant.h>
#include <kdialog.h>
#include <qpushbutton.h>
#include <klistviewsearchline.h>
#include <qlabel.h>
#include <qsplitter.h>
#include <klistbox.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include "klistviewsearchline.h"
#include "kdcoplistview.h"
#include "klistbox.h"

/*
 *  Constructs a kdcopview as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 */
kdcopview::kdcopview( QWidget* parent, const char* name, WFlags fl )
    : QWidget( parent, name, fl )
{
    if ( !name )
	setName( "kdcopview" );
    kdcopviewLayout = new QGridLayout( this, 1, 1, 0, KDialog::spacingHint(), "kdcopviewLayout"); 

    kListViewSearchLine1 = new KListViewSearchLine( this, "kListViewSearchLine1" );

    kdcopviewLayout->addWidget( kListViewSearchLine1, 0, 1 );

    textLabel1 = new QLabel( this, "textLabel1" );

    kdcopviewLayout->addWidget( textLabel1, 0, 0 );

    splitter8 = new QSplitter( this, "splitter8" );
    splitter8->setOrientation( QSplitter::Vertical );

    lv = new KDCOPListView( splitter8, "lv" );

    QWidget* privateLayoutWidget = new QWidget( splitter8, "layout18" );
    layout18 = new QGridLayout( privateLayoutWidget, 1, 1, KDialog::marginHint(), KDialog::spacingHint(), "layout18"); 

    l_replyType = new QLabel( privateLayoutWidget, "l_replyType" );
    l_replyType->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)3, (QSizePolicy::SizeType)0, 0, 0, l_replyType->sizePolicy().hasHeightForWidth() ) );
    l_replyType->setFrameShape( QLabel::NoFrame );
    l_replyType->setFrameShadow( QLabel::Raised );
    l_replyType->setIndent( 0 );

    layout18->addWidget( l_replyType, 0, 1 );

    lb_replyData = new KListBox( privateLayoutWidget, "lb_replyData" );

    layout18->addMultiCellWidget( lb_replyData, 1, 1, 0, 1 );

    TextLabel1 = new QLabel( privateLayoutWidget, "TextLabel1" );
    TextLabel1->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, TextLabel1->sizePolicy().hasHeightForWidth() ) );
    TextLabel1->setMinimumSize( QSize( 0, 0 ) );

    layout18->addWidget( TextLabel1, 0, 0 );

    kdcopviewLayout->addMultiCellWidget( splitter8, 1, 1, 0, 1 );
    languageChange();
    resize( QSize(392, 356).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );

    // buddies
    textLabel1->setBuddy( kListViewSearchLine1 );
}

/*
 *  Destroys the object and frees any allocated resources
 */
kdcopview::~kdcopview()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void kdcopview::languageChange()
{
    textLabel1->setText( tr2i18n( "&Search:" ) );
    l_replyType->setText( tr2i18n( "none" ) );
    TextLabel1->setText( tr2i18n( "Returned data type:" ) );
}

#include "kdcopview.moc"
