#include <kdialog.h>
#include <klocale.h>
/****************************************************************************
** Form implementation generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/kio/uagentproviderdlg_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "uagentproviderdlg_ui.h"

#include <qvariant.h>
#include <kdialog.h>
#include <qlabel.h>
#include <klineedit.h>
#include <kcombobox.h>
#include <qpushbutton.h>
#include <qframe.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include "klineedit.h"
#include "kcombobox.h"

/*
 *  Constructs a UAProviderDlgUI as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 */
UAProviderDlgUI::UAProviderDlgUI( QWidget* parent, const char* name, WFlags fl )
    : QWidget( parent, name, fl )
{
    if ( !name )
	setName( "UAProviderDlgUI" );
    setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)5, 0, 0, sizePolicy().hasHeightForWidth() ) );
    UAProviderDlgUILayout = new QGridLayout( this, 1, 1, KDialog::marginHint(), KDialog::spacingHint(), "UAProviderDlgUILayout"); 

    lbSite = new QLabel( this, "lbSite" );

    UAProviderDlgUILayout->addWidget( lbSite, 0, 0 );

    leSite = new KLineEdit( this, "leSite" );

    UAProviderDlgUILayout->addWidget( leSite, 1, 0 );

    lbAlias = new QLabel( this, "lbAlias" );

    UAProviderDlgUILayout->addWidget( lbAlias, 2, 0 );

    cbAlias = new KComboBox( FALSE, this, "cbAlias" );

    UAProviderDlgUILayout->addWidget( cbAlias, 3, 0 );

    lbIdentity = new QLabel( this, "lbIdentity" );

    UAProviderDlgUILayout->addWidget( lbIdentity, 4, 0 );

    leIdentity = new KLineEdit( this, "leIdentity" );
    leIdentity->setReadOnly( TRUE );

    UAProviderDlgUILayout->addWidget( leIdentity, 5, 0 );
    spacer3 = new QSpacerItem( 21, 16, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding );
    UAProviderDlgUILayout->addItem( spacer3, 6, 0 );

    layout3 = new QHBoxLayout( 0, 0, KDialog::spacingHint(), "layout3"); 
    spacer2 = new QSpacerItem( 29, 20, QSizePolicy::MinimumExpanding, QSizePolicy::Minimum );
    layout3->addItem( spacer2 );

    pbOk = new QPushButton( this, "pbOk" );
    pbOk->setEnabled( FALSE );
    layout3->addWidget( pbOk );

    pbCancel = new QPushButton( this, "pbCancel" );
    layout3->addWidget( pbCancel );

    UAProviderDlgUILayout->addLayout( layout3, 8, 0 );

    line1 = new QFrame( this, "line1" );
    line1->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)3, (QSizePolicy::SizeType)0, 0, 0, line1->sizePolicy().hasHeightForWidth() ) );
    line1->setFrameShape( QFrame::HLine );
    line1->setFrameShadow( QFrame::Sunken );
    line1->setFrameShape( QFrame::HLine );

    UAProviderDlgUILayout->addWidget( line1, 7, 0 );
    languageChange();
    resize( QSize(298, 240).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );

    // buddies
    lbSite->setBuddy( leSite );
    lbAlias->setBuddy( leIdentity );
    lbIdentity->setBuddy( leIdentity );
}

/*
 *  Destroys the object and frees any allocated resources
 */
UAProviderDlgUI::~UAProviderDlgUI()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void UAProviderDlgUI::languageChange()
{
    lbSite->setText( tr2i18n( "&When browsing the following site:" ) );
    QWhatsThis::add( lbSite, tr2i18n( "<qt>\n"
"Enter the site or domain name where a fake browser identification should be used.<p>\n"
"<u>NOTE:</u> Wildcard syntax such as \\\"*,?\\\" is NOT allowed: instead, use the top level address of a site to make generic matches; for example, if you want all KDE sites to receive a fake browser identification, you would enter <code>.kde.org</code> - the fake identity would then be sent to any KDE site that ends with <code>.kde.org</code>.\n"
"</qt>" ) );
    QWhatsThis::add( leSite, tr2i18n( "<qt>\n"
"Enter the site or domain name where a fake browser identification should be used.<p>\n"
"<u>NOTE:</u> Wildcard syntax such as \\\"*,?\\\" is NOT allowed: instead, use the top level address of a site to make generic matches; for example, if you want all KDE sites to receive a fake browser identification, you would enter <code>.kde.org</code> - the fake identity would then be sent to any KDE site that ends with <code>.kde.org</code>.\n"
"</qt>" ) );
    lbAlias->setText( tr2i18n( "&Use the following identification:" ) );
    QWhatsThis::add( lbAlias, tr2i18n( "<qt>\n"
"Select the browser identification to use whenever contacting the site you specified above.\n"
"</qt>" ) );
    QWhatsThis::add( cbAlias, tr2i18n( "<qt>\n"
"Select the browser identification to use whenever contacting the site you specified above.\n"
"</qt>" ) );
    lbIdentity->setText( tr2i18n( "Real identification:" ) );
    QWhatsThis::add( lbIdentity, tr2i18n( "<qt>\n"
"The actual browser identification text that will be sent to the remote machine.\n"
"</qt>" ) );
    QWhatsThis::add( leIdentity, tr2i18n( "<qt>\n"
"The actual browser identification text that will be sent to the remote machine.\n"
"</qt>" ) );
    pbOk->setText( tr2i18n( "&OK" ) );
    pbCancel->setText( tr2i18n( "&Cancel" ) );
}

#include "uagentproviderdlg_ui.moc"
