#include <kdialog.h>
#include <klocale.h>
/****************************************************************************
** Form implementation generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/css/preview.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "preview.h"

#include <qvariant.h>
#include <kdialog.h>
#include <kseparator.h>
#include <qtextbrowser.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include "kseparator.h"

/*
 *  Constructs a PreviewDialog as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
PreviewDialog::PreviewDialog( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
    if ( !name )
	setName( "PreviewDialog" );
    PreviewDialogLayout = new QGridLayout( this, 1, 1, KDialog::marginHint(), KDialog::spacingHint(), "PreviewDialogLayout"); 

    Line1 = new KSeparator( this, "Line1" );
    Line1->setOrientation( 5 );

    PreviewDialogLayout->addMultiCellWidget( Line1, 1, 1, 0, 1 );
    Spacer1 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    PreviewDialogLayout->addItem( Spacer1, 2, 0 );

    preview = new QTextBrowser( this, "preview" );

    PreviewDialogLayout->addMultiCellWidget( preview, 0, 0, 0, 1 );

    PushButton2 = new QPushButton( this, "PushButton2" );
    PushButton2->setDefault( TRUE );

    PreviewDialogLayout->addWidget( PushButton2, 2, 1 );
    languageChange();
    resize( QSize(558, 349).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );

    // signals and slots connections
    connect( PushButton2, SIGNAL( clicked() ), this, SLOT( accept() ) );
}

/*
 *  Destroys the object and frees any allocated resources
 */
PreviewDialog::~PreviewDialog()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void PreviewDialog::languageChange()
{
    setCaption( tr2i18n( "Preview" ) );
    preview->setText( tr2i18n( "<qt>\n"
"\n"
"<h1>Heading 1</h1><br/>\n"
"<h2>Heading 2</h2><br/>\n"
"<h3>Heading 3</h3><br/>\n"
"\n"
"<p>User defined stylesheets allow increased\n"
"accessibility for visually handicapped\n"
"people.</p>\n"
"\n"
"</qt>" ) );
    PushButton2->setText( tr2i18n( "&OK" ) );
}

#include "preview.moc"
