/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/kio/uagentproviderdlg_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef UAPROVIDERDLGUI_H
#define UAPROVIDERDLGUI_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QLabel;
class KLineEdit;
class KComboBox;
class QPushButton;
class QFrame;

class UAProviderDlgUI : public QWidget
{
    Q_OBJECT

public:
    UAProviderDlgUI( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~UAProviderDlgUI();

    QLabel* lbSite;
    KLineEdit* leSite;
    QLabel* lbAlias;
    KComboBox* cbAlias;
    QLabel* lbIdentity;
    KLineEdit* leIdentity;
    QPushButton* pbOk;
    QPushButton* pbCancel;
    QFrame* line1;

protected:
    QGridLayout* UAProviderDlgUILayout;
    QSpacerItem* spacer3;
    QHBoxLayout* layout3;
    QSpacerItem* spacer2;

protected slots:
    virtual void languageChange();

};

#endif // UAPROVIDERDLGUI_H
