/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/smserver/smserverconfigdlg.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef SMSERVERCONFIGDLG_H
#define SMSERVERCONFIGDLG_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QGroupBox;
class QCheckBox;
class QButtonGroup;
class QRadioButton;
class QLabel;
class KLineEdit;

class SMServerConfigDlg : public QWidget
{
    Q_OBJECT

public:
    SMServerConfigDlg( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~SMServerConfigDlg();

    QGroupBox* topBox;
    QCheckBox* confirmLogoutCheck;
    QCheckBox* offerShutdownCheck;
    QButtonGroup* loginGroup;
    QRadioButton* previousSessionRadio;
    QRadioButton* savedSessionRadio;
    QRadioButton* emptySessionRadio;
    QButtonGroup* sdGroup;
    QRadioButton* logoutRadio;
    QRadioButton* haltRadio;
    QRadioButton* rebootRadio;
    QButtonGroup* advancedGroup;
    QLabel* textLabel1;
    KLineEdit* excludeLineedit;

public slots:
    virtual void configChanged();

protected:
    QVBoxLayout* SMServerConfigDlgLayout;
    QSpacerItem* bottomSpacer;
    QVBoxLayout* topBoxLayout;
    QVBoxLayout* loginGroupLayout;
    QVBoxLayout* sdGroupLayout;
    QVBoxLayout* advancedGroupLayout;

protected slots:
    virtual void languageChange();

};

#endif // SMSERVERCONFIGDLG_H
