/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/input/logitechmouse_base.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef LOGITECHMOUSEBASE_H
#define LOGITECHMOUSEBASE_H

#include <qvariant.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QLabel;
class QButtonGroup;
class QRadioButton;
class QGroupBox;
class QProgressBar;

class LogitechMouseBase : public QDialog
{
    Q_OBJECT

public:
    LogitechMouseBase( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~LogitechMouseBase();

    QLabel* cordlessNameLabel;
    QLabel* permissionProblemText;
    QButtonGroup* resolutionSelector;
    QRadioButton* button400cpi;
    QRadioButton* button800cpi;
    QGroupBox* batteryBox;
    QProgressBar* batteryBar;
    QButtonGroup* channelSelector;
    QRadioButton* channel1;
    QRadioButton* channel2;

protected:
    QGridLayout* LogitechMouseBaseLayout;
    QHBoxLayout* resolutionSelectorLayout;
    QHBoxLayout* batteryBoxLayout;
    QHBoxLayout* channelSelectorLayout;

protected slots:
    virtual void languageChange();

};

#endif // LOGITECHMOUSEBASE_H
