/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/input/kmousedlg.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef KMOUSEDLG_H
#define KMOUSEDLG_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QButtonGroup;
class QRadioButton;
class QLabel;
class QCheckBox;
class QGroupBox;
class QFrame;
class QSlider;

class KMouseDlg : public QWidget
{
    Q_OBJECT

public:
    KMouseDlg( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~KMouseDlg();

    QButtonGroup* handedBox;
    QRadioButton* rightHanded;
    QRadioButton* leftHanded;
    QLabel* mousePix;
    QCheckBox* cbScrollPolarity;
    QGroupBox* GroupBox1;
    QRadioButton* doubleClick;
    QFrame* Line1;
    QCheckBox* cbVisualActivate;
    QCheckBox* cb_pointershape;
    QCheckBox* cbAutoSelect;
    QLabel* lb_short;
    QSlider* slAutoSelect;
    QLabel* lDelay;
    QLabel* lb_long;
    QRadioButton* singleClick;

protected:
    QVBoxLayout* KMouseDlgLayout;
    QSpacerItem* Spacer7;
    QGridLayout* handedBoxLayout;
    QSpacerItem* Spacer1;
    QSpacerItem* Spacer53;
    QGridLayout* GroupBox1Layout;
    QSpacerItem* Spacer6;
    QSpacerItem* Spacer3;
    QGridLayout* layout7;
    QSpacerItem* Spacer8;

protected slots:
    virtual void languageChange();

};

#endif // KMOUSEDLG_H
