/****************************************************************************
**
** DCOP Skeleton generated by dcopidl2cpp from server.kidl
**
** WARNING! All changes made in this file will be lost!
**
*****************************************************************************/

#include "/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/ksmserver/server.h"

#include <kdatastream.h>


static const char* const KSMServer_ftable[8][3] = {
    { "void", "notifySlot(QString,QString,QString,QString,QString,int,int,int,int)", "notifySlot(QString,QString,QString,QString,QString,int,int,int,int)" },
    { "void", "logoutSoundFinished(int,int)", "logoutSoundFinished(int,int)" },
    { "void", "autoStart0Done()", "autoStart0Done()" },
    { "void", "autoStart1Done()", "autoStart1Done()" },
    { "void", "autoStart2Done()", "autoStart2Done()" },
    { "void", "kcmPhase1Done()", "kcmPhase1Done()" },
    { "void", "kcmPhase2Done()", "kcmPhase2Done()" },
    { 0, 0, 0 }
};
static const int KSMServer_ftable_hiddens[7] = {
    0,
    0,
    0,
    0,
    0,
    0,
    0,
};

bool KSMServer::process(const QCString &fun, const QByteArray &data, QCString& replyType, QByteArray &replyData)
{
    if ( fun == KSMServer_ftable[0][1] ) { // void notifySlot(QString,QString,QString,QString,QString,int,int,int,int)
	QString arg0;
	QString arg1;
	QString arg2;
	QString arg3;
	QString arg4;
	int arg5;
	int arg6;
	int arg7;
	int arg8;
	QDataStream arg( data, IO_ReadOnly );
	if (arg.atEnd()) return false;
	arg >> arg0;
	if (arg.atEnd()) return false;
	arg >> arg1;
	if (arg.atEnd()) return false;
	arg >> arg2;
	if (arg.atEnd()) return false;
	arg >> arg3;
	if (arg.atEnd()) return false;
	arg >> arg4;
	if (arg.atEnd()) return false;
	arg >> arg5;
	if (arg.atEnd()) return false;
	arg >> arg6;
	if (arg.atEnd()) return false;
	arg >> arg7;
	if (arg.atEnd()) return false;
	arg >> arg8;
	replyType = KSMServer_ftable[0][0]; 
	notifySlot(arg0, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8 );
    } else if ( fun == KSMServer_ftable[1][1] ) { // void logoutSoundFinished(int,int)
	int arg0;
	int arg1;
	QDataStream arg( data, IO_ReadOnly );
	if (arg.atEnd()) return false;
	arg >> arg0;
	if (arg.atEnd()) return false;
	arg >> arg1;
	replyType = KSMServer_ftable[1][0]; 
	logoutSoundFinished(arg0, arg1 );
    } else if ( fun == KSMServer_ftable[2][1] ) { // void autoStart0Done()
	replyType = KSMServer_ftable[2][0]; 
	autoStart0Done( );
    } else if ( fun == KSMServer_ftable[3][1] ) { // void autoStart1Done()
	replyType = KSMServer_ftable[3][0]; 
	autoStart1Done( );
    } else if ( fun == KSMServer_ftable[4][1] ) { // void autoStart2Done()
	replyType = KSMServer_ftable[4][0]; 
	autoStart2Done( );
    } else if ( fun == KSMServer_ftable[5][1] ) { // void kcmPhase1Done()
	replyType = KSMServer_ftable[5][0]; 
	kcmPhase1Done( );
    } else if ( fun == KSMServer_ftable[6][1] ) { // void kcmPhase2Done()
	replyType = KSMServer_ftable[6][0]; 
	kcmPhase2Done( );
    } else {
	return KSMServerInterface::process( fun, data, replyType, replyData );
    }
    return true;
}

QCStringList KSMServer::interfaces()
{
    QCStringList ifaces = KSMServerInterface::interfaces();
    ifaces += "KSMServer";
    return ifaces;
}

QCStringList KSMServer::functions()
{
    QCStringList funcs = KSMServerInterface::functions();
    for ( int i = 0; KSMServer_ftable[i][2]; i++ ) {
	if (KSMServer_ftable_hiddens[i])
	    continue;
	QCString func = KSMServer_ftable[i][0];
	func += ' ';
	func += KSMServer_ftable[i][2];
	funcs << func;
    }
    return funcs;
}


