/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/kio/manualproxy_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef MANUALPROXYDLGUI_H
#define MANUALPROXYDLGUI_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QGroupBox;
class QLabel;
class KLineEdit;
class KIntSpinBox;
class QCheckBox;
class QPushButton;
class KListBox;
class QListBoxItem;

class ManualProxyDlgUI : public QWidget
{
    Q_OBJECT

public:
    ManualProxyDlgUI( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~ManualProxyDlgUI();

    QGroupBox* gbServers;
    QLabel* lbFtp;
    QLabel* lbHttps;
    QLabel* lbHttp;
    KLineEdit* leHttp;
    KLineEdit* leHttps;
    KLineEdit* leFtp;
    KIntSpinBox* sbFtp;
    KIntSpinBox* sbHttps;
    KIntSpinBox* sbHttp;
    QCheckBox* cbSameProxy;
    QPushButton* pbCopyDown;
    QGroupBox* gbExceptions;
    QCheckBox* cbReverseProxy;
    QPushButton* pbDeleteAll;
    QPushButton* pbDelete;
    QPushButton* pbNew;
    QPushButton* pbChange;
    KListBox* lbExceptions;

protected:
    QVBoxLayout* ManualProxyDlgUILayout;
    QGridLayout* gbServersLayout;
    QSpacerItem* spacer1;
    QVBoxLayout* gbExceptionsLayout;
    QGridLayout* layout2;
    QSpacerItem* spacer2;

protected slots:
    virtual void languageChange();

};

#endif // MANUALPROXYDLGUI_H
