/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/privacy/kcmprivacydialog.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef KCMPRIVACYDIALOG_H
#define KCMPRIVACYDIALOG_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QSplitter;
class KListView;
class QListViewItem;
class KTextEdit;
class QPushButton;

class KCMPrivacyDialog : public QWidget
{
    Q_OBJECT

public:
    KCMPrivacyDialog( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~KCMPrivacyDialog();

    QSplitter* splitter1;
    KListView* privacyListView;
    KTextEdit* statusTextEdit;
    QPushButton* selectAllButton;
    QPushButton* selectNoneButton;
    QPushButton* cleanupButton;

protected:
    QVBoxLayout* KCMPrivacyDialogLayout;
    QHBoxLayout* layout1;
    QSpacerItem* spacer1;

protected slots:
    virtual void languageChange();

};

#endif // KCMPRIVACYDIALOG_H
