/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/componentchooser/componentchooser_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef COMPONENTCHOOSER_UI_H
#define COMPONENTCHOOSER_UI_H

#include <qvariant.h>
#include <qwidget.h>
#include <klistbox.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QGroupBox;
class QWidgetStack;
class QLabel;
class KListBox;
class QListBoxItem;

class ComponentChooser_UI : public QWidget
{
    Q_OBJECT

public:
    ComponentChooser_UI( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~ComponentChooser_UI();

    QGroupBox* GroupBox1;
    QWidgetStack* configContainer;
    QGroupBox* GroupBox2;
    QLabel* ComponentDescription;
    KListBox* ServiceChooser;

protected:
    QGridLayout* ComponentChooser_UILayout;
    QVBoxLayout* GroupBox1Layout;
    QVBoxLayout* GroupBox2Layout;

protected slots:
    virtual void languageChange();

};

#endif // COMPONENTCHOOSER_UI_H
