/****************************************************************************
**
** DCOP Skeleton generated by dcopidl2cpp from systemdirnotifymodule.kidl
**
** WARNING! All changes made in this file will be lost!
**
*****************************************************************************/

#include "/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kioslave/system/kdedmodule/systemdirnotifymodule.h"

#include <kdatastream.h>


static const char* const SystemDirNotifyModule_ftable[1][3] = {
    { 0, 0, 0 }
};

bool SystemDirNotifyModule::process(const QCString &fun, const QByteArray &data, QCString& replyType, QByteArray &replyData)
{
	return KDEDModule::process( fun, data, replyType, replyData );
}

QCStringList SystemDirNotifyModule::interfaces()
{
    QCStringList ifaces = KDEDModule::interfaces();
    ifaces += "SystemDirNotifyModule";
    return ifaces;
}

QCStringList SystemDirNotifyModule::functions()
{
    QCStringList funcs = KDEDModule::functions();
    for ( int i = 0; SystemDirNotifyModule_ftable[i][2]; i++ ) {
	QCString func = SystemDirNotifyModule_ftable[i][0];
	func += ' ';
	func += SystemDirNotifyModule_ftable[i][2];
	funcs << func;
    }
    return funcs;
}


