/****************************************************************************
**
** DCOP Skeleton generated by dcopidl2cpp from konq_faviconmgr.kidl
**
** WARNING! All changes made in this file will be lost!
**
*****************************************************************************/

#include "/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/libkonq/konq_faviconmgr.h"

#include <kdatastream.h>


static const char* const KonqFavIconMgr_ftable[2][3] = {
    { "ASYNC", "notifyChange(bool,QString,QString)", "notifyChange(bool,QString,QString)" },
    { 0, 0, 0 }
};
static const int KonqFavIconMgr_ftable_hiddens[1] = {
    0,
};

bool KonqFavIconMgr::process(const QCString &fun, const QByteArray &data, QCString& replyType, QByteArray &replyData)
{
    if ( fun == KonqFavIconMgr_ftable[0][1] ) { // void notifyChange(bool,QString,QString)
	bool arg0;
	QString arg1;
	QString arg2;
	QDataStream arg( data, IO_ReadOnly );
	if (arg.atEnd()) return false;
	arg >> arg0;
	if (arg.atEnd()) return false;
	arg >> arg1;
	if (arg.atEnd()) return false;
	arg >> arg2;
	replyType = KonqFavIconMgr_ftable[0][0]; 
	notifyChange(arg0, arg1, arg2 );
    } else {
	return DCOPObject::process( fun, data, replyType, replyData );
    }
    return true;
}

QCStringList KonqFavIconMgr::interfaces()
{
    QCStringList ifaces = DCOPObject::interfaces();
    ifaces += "KonqFavIconMgr";
    return ifaces;
}

QCStringList KonqFavIconMgr::functions()
{
    QCStringList funcs = DCOPObject::functions();
    for ( int i = 0; KonqFavIconMgr_ftable[i][2]; i++ ) {
	if (KonqFavIconMgr_ftable_hiddens[i])
	    continue;
	QCString func = KonqFavIconMgr_ftable[i][0];
	func += ' ';
	func += KonqFavIconMgr_ftable[i][2];
	funcs << func;
    }
    return funcs;
}


