#include <kdialog.h>
#include <klocale.h>
/****************************************************************************
** Form implementation generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/privacy/kprivacysettings.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "kprivacysettings.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qframe.h>
#include <qlabel.h>
#include <qcombobox.h>
#include <qbuttongroup.h>
#include <qcheckbox.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include "kdialog.h"

/*
 *  Constructs a KPrivacySettings as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 */
KPrivacySettings::KPrivacySettings( QWidget* parent, const char* name, WFlags fl )
    : QWidget( parent, name, fl )
{
    if ( !name )
	setName( "KPrivacySettings" );
    KPrivacySettingsLayout = new QGridLayout( this, 1, 1, KDialog::marginHint(), KDialog::spacingHint(), "KPrivacySettingsLayout"); 

    line1 = new QFrame( this, "line1" );
    line1->setFrameShape( QFrame::HLine );
    line1->setFrameShadow( QFrame::Sunken );
    line1->setFrameShape( QFrame::HLine );

    KPrivacySettingsLayout->addMultiCellWidget( line1, 1, 1, 0, 1 );

    textLabel1 = new QLabel( this, "textLabel1" );

    KPrivacySettingsLayout->addWidget( textLabel1, 0, 0 );

    _privacyLevel = new QComboBox( FALSE, this, "_privacyLevel" );
    _privacyLevel->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7, (QSizePolicy::SizeType)0, 0, 0, _privacyLevel->sizePolicy().hasHeightForWidth() ) );

    KPrivacySettingsLayout->addWidget( _privacyLevel, 0, 1 );

    buttonGroup1_2 = new QButtonGroup( this, "buttonGroup1_2" );
    buttonGroup1_2->setColumnLayout(0, Qt::Vertical );
    buttonGroup1_2->layout()->setSpacing( KDialog::spacingHint() );
    buttonGroup1_2->layout()->setMargin( KDialog::marginHint() );
    buttonGroup1_2Layout = new QVBoxLayout( buttonGroup1_2->layout() );
    buttonGroup1_2Layout->setAlignment( Qt::AlignTop );

    textLabel2 = new QLabel( buttonGroup1_2, "textLabel2" );
    buttonGroup1_2Layout->addWidget( textLabel2 );

    _warnFinancialMarketeer = new QCheckBox( buttonGroup1_2, "_warnFinancialMarketeer" );
    buttonGroup1_2Layout->addWidget( _warnFinancialMarketeer );

    _warnFinancialSpammer = new QCheckBox( buttonGroup1_2, "_warnFinancialSpammer" );
    buttonGroup1_2Layout->addWidget( _warnFinancialSpammer );

    KPrivacySettingsLayout->addMultiCellWidget( buttonGroup1_2, 6, 6, 0, 1 );

    buttonGroup1 = new QButtonGroup( this, "buttonGroup1" );
    buttonGroup1->setColumnLayout(0, Qt::Vertical );
    buttonGroup1->layout()->setSpacing( KDialog::spacingHint() );
    buttonGroup1->layout()->setMargin( KDialog::marginHint() );
    buttonGroup1Layout = new QVBoxLayout( buttonGroup1->layout() );
    buttonGroup1Layout->setAlignment( Qt::AlignTop );

    textLabel2_2 = new QLabel( buttonGroup1, "textLabel2_2" );
    buttonGroup1Layout->addWidget( textLabel2_2 );

    _warnHealthMarketeer = new QCheckBox( buttonGroup1, "_warnHealthMarketeer" );
    buttonGroup1Layout->addWidget( _warnHealthMarketeer );

    _warnHealthSpammer = new QCheckBox( buttonGroup1, "_warnHealthSpammer" );
    buttonGroup1Layout->addWidget( _warnHealthSpammer );

    KPrivacySettingsLayout->addMultiCellWidget( buttonGroup1, 5, 5, 0, 1 );

    buttonGroup1_2_2 = new QButtonGroup( this, "buttonGroup1_2_2" );
    buttonGroup1_2_2->setColumnLayout(0, Qt::Vertical );
    buttonGroup1_2_2->layout()->setSpacing( KDialog::spacingHint() );
    buttonGroup1_2_2->layout()->setMargin( KDialog::marginHint() );
    buttonGroup1_2_2Layout = new QVBoxLayout( buttonGroup1_2_2->layout() );
    buttonGroup1_2_2Layout->setAlignment( Qt::AlignTop );

    textLabel2_3 = new QLabel( buttonGroup1_2_2, "textLabel2_3" );
    buttonGroup1_2_2Layout->addWidget( textLabel2_3 );

    _warnDemographicsBigBrother = new QCheckBox( buttonGroup1_2_2, "_warnDemographicsBigBrother" );
    buttonGroup1_2_2Layout->addWidget( _warnDemographicsBigBrother );

    _warnDemographicsSpammer = new QCheckBox( buttonGroup1_2_2, "_warnDemographicsSpammer" );
    buttonGroup1_2_2Layout->addWidget( _warnDemographicsSpammer );

    KPrivacySettingsLayout->addMultiCellWidget( buttonGroup1_2_2, 7, 7, 0, 1 );

    _warnSpammers = new QCheckBox( this, "_warnSpammers" );

    KPrivacySettingsLayout->addMultiCellWidget( _warnSpammers, 2, 2, 0, 1 );

    _warnShady = new QCheckBox( this, "_warnShady" );

    KPrivacySettingsLayout->addMultiCellWidget( _warnShady, 3, 3, 0, 1 );

    buttonGroup4 = new QButtonGroup( this, "buttonGroup4" );
    buttonGroup4->setColumnLayout(0, Qt::Vertical );
    buttonGroup4->layout()->setSpacing( KDialog::spacingHint() );
    buttonGroup4->layout()->setMargin( KDialog::marginHint() );
    buttonGroup4Layout = new QGridLayout( buttonGroup4->layout() );
    buttonGroup4Layout->setAlignment( Qt::AlignTop );

    textLabel2_2_2 = new QLabel( buttonGroup4, "textLabel2_2_2" );

    buttonGroup4Layout->addMultiCellWidget( textLabel2_2_2, 0, 0, 0, 1 );

    textLabel2_2_2_2 = new QLabel( buttonGroup4, "textLabel2_2_2_2" );

    buttonGroup4Layout->addMultiCellWidget( textLabel2_2_2_2, 2, 2, 0, 1 );

    _warnPersonalHabits = new QCheckBox( buttonGroup4, "_warnPersonalHabits" );

    buttonGroup4Layout->addMultiCellWidget( _warnPersonalHabits, 3, 3, 0, 1 );

    layout1 = new QVBoxLayout( 0, 0, KDialog::spacingHint(), "layout1"); 

    _warnPersonalTelephone = new QCheckBox( buttonGroup4, "_warnPersonalTelephone" );
    layout1->addWidget( _warnPersonalTelephone );

    _warnPersonalMail = new QCheckBox( buttonGroup4, "_warnPersonalMail" );
    layout1->addWidget( _warnPersonalMail );

    buttonGroup4Layout->addLayout( layout1, 1, 0 );

    layout3 = new QVBoxLayout( 0, 0, KDialog::spacingHint(), "layout3"); 

    _warnPersonalEmail = new QCheckBox( buttonGroup4, "_warnPersonalEmail" );
    layout3->addWidget( _warnPersonalEmail );

    _warnPersonalBigBrother = new QCheckBox( buttonGroup4, "_warnPersonalBigBrother" );
    layout3->addWidget( _warnPersonalBigBrother );

    buttonGroup4Layout->addLayout( layout3, 1, 1 );

    KPrivacySettingsLayout->addMultiCellWidget( buttonGroup4, 4, 4, 0, 1 );
    languageChange();
    resize( QSize(905, 724).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );

    // buddies
    textLabel1->setBuddy( _privacyLevel );
}

/*
 *  Destroys the object and frees any allocated resources
 */
KPrivacySettings::~KPrivacySettings()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void KPrivacySettings::languageChange()
{
    setCaption( tr2i18n( "Privacy Settings" ) );
    textLabel1->setText( tr2i18n( "Network privacy level:" ) );
    _privacyLevel->clear();
    _privacyLevel->insertItem( tr2i18n( "Low" ) );
    _privacyLevel->insertItem( tr2i18n( "Medium" ) );
    _privacyLevel->insertItem( tr2i18n( "High" ) );
    _privacyLevel->insertItem( tr2i18n( "Custom" ) );
    buttonGroup1_2->setTitle( tr2i18n( "Financial Information" ) );
    textLabel2->setText( tr2i18n( "Warn me when I visit a site that uses my financial or purchase information:" ) );
    _warnFinancialMarketeer->setText( tr2i18n( "For marketing or advertising purposes" ) );
    _warnFinancialSpammer->setText( tr2i18n( "To share with other companies" ) );
    buttonGroup1->setTitle( tr2i18n( "Health Information" ) );
    textLabel2_2->setText( tr2i18n( "Warn me when I visit a site that uses my health or medical information: " ) );
    _warnHealthMarketeer->setText( tr2i18n( "For marketing or advertising purposes" ) );
    _warnHealthSpammer->setText( tr2i18n( "To share with other companies" ) );
    buttonGroup1_2_2->setTitle( tr2i18n( "Demographics" ) );
    textLabel2_3->setText( tr2i18n( "Warn me when I visit a site that uses my non-personally identifiable information:" ) );
    _warnDemographicsBigBrother->setText( tr2i18n( "To determine my interests, habits or general behavior" ) );
    _warnDemographicsSpammer->setText( tr2i18n( "To share with other companies" ) );
    _warnSpammers->setText( tr2i18n( "Warn me when I visit a site that shares my personal information with other companies" ) );
    _warnShady->setText( tr2i18n( "Warn me when I visit a site that does not let me know what information they have about me" ) );
    buttonGroup4->setTitle( tr2i18n( "Personal Information" ) );
    textLabel2_2_2->setText( tr2i18n( "Warn me when I visit a site that may contact me about other products or services:" ) );
    textLabel2_2_2_2->setText( tr2i18n( "Warn me when I visit a site that may use my personal information to:" ) );
    _warnPersonalHabits->setText( tr2i18n( "Determine my habits, interests or general behavior" ) );
    _warnPersonalTelephone->setText( tr2i18n( "Via telephone" ) );
    _warnPersonalMail->setText( tr2i18n( "Via mail" ) );
    _warnPersonalEmail->setText( tr2i18n( "Via email" ) );
    _warnPersonalBigBrother->setText( tr2i18n( "And do not allow me to remove my contact information" ) );
}

#include "kprivacysettings.moc"
