/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/privacy/kprivacysettings.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef KPRIVACYSETTINGS_H
#define KPRIVACYSETTINGS_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QFrame;
class QLabel;
class QComboBox;
class QButtonGroup;
class QCheckBox;

class KPrivacySettings : public QWidget
{
    Q_OBJECT

public:
    KPrivacySettings( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~KPrivacySettings();

    QFrame* line1;
    QLabel* textLabel1;
    QComboBox* _privacyLevel;
    QButtonGroup* buttonGroup1_2;
    QLabel* textLabel2;
    QCheckBox* _warnFinancialMarketeer;
    QCheckBox* _warnFinancialSpammer;
    QButtonGroup* buttonGroup1;
    QLabel* textLabel2_2;
    QCheckBox* _warnHealthMarketeer;
    QCheckBox* _warnHealthSpammer;
    QButtonGroup* buttonGroup1_2_2;
    QLabel* textLabel2_3;
    QCheckBox* _warnDemographicsBigBrother;
    QCheckBox* _warnDemographicsSpammer;
    QCheckBox* _warnSpammers;
    QCheckBox* _warnShady;
    QButtonGroup* buttonGroup4;
    QLabel* textLabel2_2_2;
    QLabel* textLabel2_2_2_2;
    QCheckBox* _warnPersonalHabits;
    QCheckBox* _warnPersonalTelephone;
    QCheckBox* _warnPersonalMail;
    QCheckBox* _warnPersonalEmail;
    QCheckBox* _warnPersonalBigBrother;

protected:
    QGridLayout* KPrivacySettingsLayout;
    QVBoxLayout* buttonGroup1_2Layout;
    QVBoxLayout* buttonGroup1Layout;
    QVBoxLayout* buttonGroup1_2_2Layout;
    QGridLayout* buttonGroup4Layout;
    QVBoxLayout* layout1;
    QVBoxLayout* layout3;

protected slots:
    virtual void languageChange();

};

#endif // KPRIVACYSETTINGS_H
