/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/componentchooser/browserconfig_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef BROWSERCONFIG_UI_H
#define BROWSERCONFIG_UI_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QButtonGroup;
class QLabel;
class QRadioButton;
class QLineEdit;
class QToolButton;

class BrowserConfig_UI : public QWidget
{
    Q_OBJECT

public:
    BrowserConfig_UI( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~BrowserConfig_UI();

    QButtonGroup* buttonGroup1;
    QLabel* label;
    QRadioButton* radioKIO;
    QRadioButton* radioExec;
    QLineEdit* lineExec;
    QToolButton* btnSelectBrowser;

protected:
    QVBoxLayout* BrowserConfig_UILayout;
    QSpacerItem* spacer9;
    QVBoxLayout* buttonGroup1Layout;
    QHBoxLayout* layout3;
    QSpacerItem* spacer4_2;

protected slots:
    virtual void languageChange();

    virtual void selectBrowser();


};

#endif // BROWSERCONFIG_UI_H
