/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/kio/kcookiesmanagementdlg_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef KCOOKIESMANAGEMENTDLGUI_H
#define KCOOKIESMANAGEMENTDLGUI_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class KListView;
class QListViewItem;
class QPushButton;
class QToolButton;
class QLabel;
class KListViewSearchLine;
class QGroupBox;
class KLineEdit;

class KCookiesManagementDlgUI : public QWidget
{
    Q_OBJECT

public:
    KCookiesManagementDlgUI( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~KCookiesManagementDlgUI();

    KListView* lvCookies;
    QPushButton* pbDelete;
    QPushButton* pbDeleteAll;
    QPushButton* pbPolicy;
    QPushButton* pbReload;
    QToolButton* tbClearSearchLine;
    QLabel* textLabel1;
    KListViewSearchLine* kListViewSearchLine;
    QGroupBox* gbDetails;
    KLineEdit* leDomain;
    KLineEdit* lePath;
    KLineEdit* leSecure;
    QLabel* lbName;
    QLabel* lbValue;
    QLabel* lbDomain;
    QLabel* lbPath;
    QLabel* lbExpires;
    QLabel* lbSecure;
    KLineEdit* leValue;
    KLineEdit* leExpires;
    KLineEdit* leName;

protected:
    QGridLayout* KCookiesManagementDlgUILayout;
    QGridLayout* layout6;
    QVBoxLayout* layout4;
    QSpacerItem* spacer3;
    QHBoxLayout* layout3;
    QGridLayout* gbDetailsLayout;

protected slots:
    virtual void languageChange();

};

#endif // KCOOKIESMANAGEMENTDLGUI_H
