/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/dnssd/configdialog.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef CONFIGDIALOG_H
#define CONFIGDIALOG_H

#include <qvariant.h>
#include <kcmodule.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QTabWidget;
class QWidget;
class QCheckBox;
class KEditListBox;
class QButtonGroup;
class QRadioButton;
class QLabel;
class KLineEdit;
class KPasswordEdit;

class ConfigDialog : public KCModule
{
    Q_OBJECT

public:
    ConfigDialog( QWidget* parent = 0, const char* name = 0 );
    ~ConfigDialog();

    QTabWidget* tabs;
    QWidget* tab;
    QCheckBox* kcfg_BrowseLocal;
    KEditListBox* kcfg_DomainList;
    QButtonGroup* kcfg_PublishType;
    QRadioButton* LANButtor;
    QRadioButton* WANButton;
    QWidget* tab_2;
    QLabel* textLabel2;
    KLineEdit* hostedit;
    KPasswordEdit* secretedit;
    QLabel* domainLabel;
    QLabel* textLabel1;
    KLineEdit* domainedit;

public slots:
    virtual void radioButton2_2_toggled(bool);

protected:
    QGridLayout* ConfigDialogLayout;
    QVBoxLayout* tabLayout;
    QVBoxLayout* tabLayout_2;
    QSpacerItem* spacer7;
    QGridLayout* layout7;
    QSpacerItem* spacer4;
    QSpacerItem* spacer1;
    QSpacerItem* spacer5;

protected slots:
    virtual void languageChange();

};

#endif // CONFIGDIALOG_H
