/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/componentchooser/terminalemulatorconfig_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef TERMINALEMULATORCONFIG_UI_H
#define TERMINALEMULATORCONFIG_UI_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QButtonGroup;
class QRadioButton;
class QLineEdit;
class QToolButton;

class TerminalEmulatorConfig_UI : public QWidget
{
    Q_OBJECT

public:
    TerminalEmulatorConfig_UI( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~TerminalEmulatorConfig_UI();

    QButtonGroup* ButtonGroup1;
    QRadioButton* otherCB;
    QRadioButton* terminalCB;
    QLineEdit* terminalLE;
    QToolButton* btnSelectTerminal;

protected:
    QVBoxLayout* TerminalEmulatorConfig_UILayout;
    QGridLayout* ButtonGroup1Layout;
    QSpacerItem* Spacer4;
    QSpacerItem* Spacer15;
    QHBoxLayout* Layout4;

protected slots:
    virtual void languageChange();

    virtual void selectTerminalApp();


};

#endif // TERMINALEMULATORCONFIG_UI_H
