/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/konsole/schemadialog.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef SCHEMADIALOG_H
#define SCHEMADIALOG_H

#include <qvariant.h>
#include <qwidget.h>
#include <kcolorbutton.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QLabel;
class QLineEdit;
class QGroupBox;
class QCheckBox;
class KColorButton;
class QComboBox;
class QListBox;
class QListBoxItem;
class QPushButton;
class QToolButton;
class QSlider;

class SchemaDialog : public QWidget
{
    Q_OBJECT

public:
    SchemaDialog( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~SchemaDialog();

    QLabel* TextLabel1;
    QLineEdit* titleLine;
    QGroupBox* GroupBox1;
    QLabel* TextLabel8;
    QCheckBox* boldCheck;
    KColorButton* colorButton;
    QComboBox* typeCombo;
    QCheckBox* transparentCheck;
    QLabel* TextLabel1_2;
    QComboBox* colorCombo;
    QGroupBox* GroupBox2;
    QListBox* schemaList;
    QCheckBox* defaultSchemaCB;
    QPushButton* saveButton;
    QPushButton* removeButton;
    QGroupBox* GroupBox13;
    QLineEdit* backgndLine;
    QToolButton* imageBrowse;
    QComboBox* modeCombo;
    QLabel* TextLabel11;
    QLabel* TextLabel6;
    QSlider* shadeSlide;
    QLabel* TextLabel5;
    QLabel* TextLabel3;
    KColorButton* shadeColor;
    QLabel* previewPixmap;
    QCheckBox* transparencyCheck;

protected:
    QGridLayout* SchemaDialogLayout;
    QSpacerItem* Spacer4;
    QHBoxLayout* Layout2;
    QGridLayout* GroupBox1Layout;
    QSpacerItem* Spacer5;
    QSpacerItem* Spacer2;
    QVBoxLayout* GroupBox2Layout;
    QGridLayout* Layout3;
    QSpacerItem* Spacer7;
    QGridLayout* GroupBox13Layout;
    QSpacerItem* Spacer1;

protected slots:
    virtual void languageChange();

};

#endif // SCHEMADIALOG_H
