/****************************************************************************
**
** DCOP Skeleton generated by dcopidl2cpp from kuriikwsfilter.kidl
**
** WARNING! All changes made in this file will be lost!
**
*****************************************************************************/

#include "/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/ebrowsing/plugins/ikws/kuriikwsfilter.h"

#include <kdatastream.h>


static const char* const KAutoWebSearch_ftable[2][3] = {
    { "void", "configure()", "configure()" },
    { 0, 0, 0 }
};
static const int KAutoWebSearch_ftable_hiddens[1] = {
    0,
};

bool KAutoWebSearch::process(const QCString &fun, const QByteArray &data, QCString& replyType, QByteArray &replyData)
{
    if ( fun == KAutoWebSearch_ftable[0][1] ) { // void configure()
	replyType = KAutoWebSearch_ftable[0][0]; 
	configure( );
    } else {
	return DCOPObject::process( fun, data, replyType, replyData );
    }
    return true;
}

QCStringList KAutoWebSearch::interfaces()
{
    QCStringList ifaces = DCOPObject::interfaces();
    ifaces += "KAutoWebSearch";
    return ifaces;
}

QCStringList KAutoWebSearch::functions()
{
    QCStringList funcs = DCOPObject::functions();
    for ( int i = 0; KAutoWebSearch_ftable[i][2]; i++ ) {
	if (KAutoWebSearch_ftable_hiddens[i])
	    continue;
	QCString func = KAutoWebSearch_ftable[i][0];
	func += ' ';
	func += KAutoWebSearch_ftable[i][2];
	funcs << func;
    }
    return funcs;
}


