/****************************************************************************
** Form interface generated from reading ui file '/usr/src/ports/kdebase3/kdebase3-3.5.10-11.x86_64/src/kdebase-3.5.10/kcontrol/componentchooser/emailclientconfig_ui.ui'
**
** Created by User Interface Compiler
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef EMAILCLIENTCONFIG_UI_H
#define EMAILCLIENTCONFIG_UI_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QButtonGroup;
class QLineEdit;
class QToolButton;
class QCheckBox;
class QRadioButton;

class EmailClientConfig_UI : public QWidget
{
    Q_OBJECT

public:
    EmailClientConfig_UI( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~EmailClientConfig_UI();

    QButtonGroup* ButtonGroup2;
    QLineEdit* txtEMailClient;
    QToolButton* btnSelectEmail;
    QCheckBox* chkRunTerminal;
    QRadioButton* kmailCB;
    QRadioButton* otherCB;

protected:
    QVBoxLayout* EmailClientConfig_UILayout;
    QGridLayout* ButtonGroup2Layout;
    QSpacerItem* Spacer2;
    QSpacerItem* Spacer16;
    QSpacerItem* Spacer16_2;
    QHBoxLayout* Layout4;

protected slots:
    virtual void languageChange();

    virtual void selectEmailClient();


};

#endif // EMAILCLIENTCONFIG_UI_H
